"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.tokenfactory.v1beta1.authorityMetadata_pb2
import osmosis.tokenfactory.v1beta1.params_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QueryParamsRequest(google.protobuf.message.Message):
    """QueryParamsRequest is the request type for the Query/Params RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryParamsRequest = QueryParamsRequest

@typing_extensions.final
class QueryParamsResponse(google.protobuf.message.Message):
    """QueryParamsResponse is the response type for the Query/Params RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> osmosis.tokenfactory.v1beta1.params_pb2.Params:
        """params defines the parameters of the module."""
    def __init__(
        self,
        *,
        params: osmosis.tokenfactory.v1beta1.params_pb2.Params | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___QueryParamsResponse = QueryParamsResponse

@typing_extensions.final
class QueryDenomAuthorityMetadataRequest(google.protobuf.message.Message):
    """QueryDenomAuthorityMetadataRequest defines the request structure for the
    DenomAuthorityMetadata gRPC query.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    denom: builtins.str
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom", b"denom"]) -> None: ...

global___QueryDenomAuthorityMetadataRequest = QueryDenomAuthorityMetadataRequest

@typing_extensions.final
class QueryDenomAuthorityMetadataResponse(google.protobuf.message.Message):
    """QueryDenomAuthorityMetadataResponse defines the response structure for the
    DenomAuthorityMetadata gRPC query.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHORITY_METADATA_FIELD_NUMBER: builtins.int
    @property
    def authority_metadata(self) -> osmosis.tokenfactory.v1beta1.authorityMetadata_pb2.DenomAuthorityMetadata: ...
    def __init__(
        self,
        *,
        authority_metadata: osmosis.tokenfactory.v1beta1.authorityMetadata_pb2.DenomAuthorityMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authority_metadata", b"authority_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authority_metadata", b"authority_metadata"]) -> None: ...

global___QueryDenomAuthorityMetadataResponse = QueryDenomAuthorityMetadataResponse

@typing_extensions.final
class QueryDenomsFromCreatorRequest(google.protobuf.message.Message):
    """QueryDenomsFromCreatorRequest defines the request structure for the
    DenomsFromCreator gRPC query.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATOR_FIELD_NUMBER: builtins.int
    creator: builtins.str
    def __init__(
        self,
        *,
        creator: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["creator", b"creator"]) -> None: ...

global___QueryDenomsFromCreatorRequest = QueryDenomsFromCreatorRequest

@typing_extensions.final
class QueryDenomsFromCreatorResponse(google.protobuf.message.Message):
    """QueryDenomsFromCreatorRequest defines the response structure for the
    DenomsFromCreator gRPC query.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOMS_FIELD_NUMBER: builtins.int
    @property
    def denoms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        denoms: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["denoms", b"denoms"]) -> None: ...

global___QueryDenomsFromCreatorResponse = QueryDenomsFromCreatorResponse
