"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the raw genesis transaction in JSON."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GEN_TXS_FIELD_NUMBER: builtins.int
    @property
    def gen_txs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]:
        """gen_txs defines the genesis transactions."""
    def __init__(
        self,
        *,
        gen_txs: collections.abc.Iterable[builtins.bytes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gen_txs", b"gen_txs"]) -> None: ...

global___GenesisState = GenesisState
