"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.lockup.lock_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MsgLockTokens(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    COINS_FIELD_NUMBER: builtins.int
    owner: builtins.str
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration: ...
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
        coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["coins", b"coins", "duration", b"duration", "owner", b"owner"]) -> None: ...

global___MsgLockTokens = MsgLockTokens

@typing_extensions.final
class MsgLockTokensResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ID: builtins.int
    def __init__(
        self,
        *,
        ID: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ID", b"ID"]) -> None: ...

global___MsgLockTokensResponse = MsgLockTokensResponse

@typing_extensions.final
class MsgBeginUnlockingAll(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    owner: builtins.str
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["owner", b"owner"]) -> None: ...

global___MsgBeginUnlockingAll = MsgBeginUnlockingAll

@typing_extensions.final
class MsgBeginUnlockingAllResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNLOCKS_FIELD_NUMBER: builtins.int
    @property
    def unlocks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.lockup.lock_pb2.PeriodLock]: ...
    def __init__(
        self,
        *,
        unlocks: collections.abc.Iterable[osmosis.lockup.lock_pb2.PeriodLock] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["unlocks", b"unlocks"]) -> None: ...

global___MsgBeginUnlockingAllResponse = MsgBeginUnlockingAllResponse

@typing_extensions.final
class MsgBeginUnlocking(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    COINS_FIELD_NUMBER: builtins.int
    owner: builtins.str
    ID: builtins.int
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """Amount of unlocking coins. Unlock all if not set."""
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
        ID: builtins.int = ...,
        coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ID", b"ID", "coins", b"coins", "owner", b"owner"]) -> None: ...

global___MsgBeginUnlocking = MsgBeginUnlocking

@typing_extensions.final
class MsgBeginUnlockingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["success", b"success"]) -> None: ...

global___MsgBeginUnlockingResponse = MsgBeginUnlockingResponse

@typing_extensions.final
class MsgExtendLockup(google.protobuf.message.Message):
    """MsgExtendLockup extends the existing lockup's duration.
    The new duration is longer than the original.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    owner: builtins.str
    ID: builtins.int
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """duration to be set. fails if lower than the current duration, or is
        unlocking
        """
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
        ID: builtins.int = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ID", b"ID", "duration", b"duration", "owner", b"owner"]) -> None: ...

global___MsgExtendLockup = MsgExtendLockup

@typing_extensions.final
class MsgExtendLockupResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["success", b"success"]) -> None: ...

global___MsgExtendLockupResponse = MsgExtendLockupResponse

@typing_extensions.final
class MsgForceUnlock(google.protobuf.message.Message):
    """MsgForceUnlock unlocks locks immediately for
    addresses registered via governance.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    COINS_FIELD_NUMBER: builtins.int
    owner: builtins.str
    ID: builtins.int
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """Amount of unlocking coins. Unlock all if not set."""
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
        ID: builtins.int = ...,
        coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ID", b"ID", "coins", b"coins", "owner", b"owner"]) -> None: ...

global___MsgForceUnlock = MsgForceUnlock

@typing_extensions.final
class MsgForceUnlockResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["success", b"success"]) -> None: ...

global___MsgForceUnlockResponse = MsgForceUnlockResponse
