"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.incentives.tx_pb2

class MsgStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    CreateGauge: grpc.UnaryUnaryMultiCallable[
        osmosis.incentives.tx_pb2.MsgCreateGauge,
        osmosis.incentives.tx_pb2.MsgCreateGaugeResponse,
    ]
    AddToGauge: grpc.UnaryUnaryMultiCallable[
        osmosis.incentives.tx_pb2.MsgAddToGauge,
        osmosis.incentives.tx_pb2.MsgAddToGaugeResponse,
    ]

class MsgServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreateGauge(
        self,
        request: osmosis.incentives.tx_pb2.MsgCreateGauge,
        context: grpc.ServicerContext,
    ) -> osmosis.incentives.tx_pb2.MsgCreateGaugeResponse: ...
    @abc.abstractmethod
    def AddToGauge(
        self,
        request: osmosis.incentives.tx_pb2.MsgAddToGauge,
        context: grpc.ServicerContext,
    ) -> osmosis.incentives.tx_pb2.MsgAddToGaugeResponse: ...

def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...
