# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/gamm/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from osmosis.gamm.v1beta1 import tx_pb2 as osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from google_apis.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n osmosis/gamm/v1beta1/query.proto\x12\x14osmosis.gamm.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1dosmosis/gamm/v1beta1/tx.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\"7\n\x10QueryPoolRequest\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\"B\n\x11QueryPoolResponse\x12-\n\x04pool\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\t\xca\xb4-\x05PoolI\"O\n\x11QueryPoolsRequest\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x81\x01\n\x12QueryPoolsResponse\x12.\n\x05pools\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyB\t\xca\xb4-\x05PoolI\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x16\n\x14QueryNumPoolsRequest\"@\n\x15QueryNumPoolsResponse\x12\'\n\tnum_pools\x18\x01 \x01(\x04\x42\x14\xf2\xde\x1f\x10yaml:\"num_pools\"\";\n\x14QueryPoolTypeRequest\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\"@\n\x15QueryPoolTypeResponse\x12\'\n\tpool_type\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"pool_type\"\"\xa5\x01\n\x1eQueryCalcJoinPoolSharesRequest\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12^\n\ttokens_in\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xc8\xde\x1f\x00\"\xe7\x01\n\x1fQueryCalcJoinPoolSharesResponse\x12\x63\n\x10share_out_amount\x18\x01 \x01(\tBI\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:\"share_out_amount\"\xc8\xde\x1f\x00\x12_\n\ntokens_out\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xc8\xde\x1f\x00\"\x83\x01\n\'QueryCalcExitPoolCoinsFromSharesRequest\x12\x0f\n\x07pool_id\x18\x01 \x01(\x04\x12G\n\x0fshare_in_amount\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"\x8b\x01\n(QueryCalcExitPoolCoinsFromSharesResponse\x12_\n\ntokens_out\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xc8\xde\x1f\x00\"=\n\x16QueryPoolParamsRequest\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\"?\n\x17QueryPoolParamsResponse\x12$\n\x06params\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"E\n\x1eQueryTotalPoolLiquidityRequest\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\"\x95\x01\n\x1fQueryTotalPoolLiquidityResponse\x12r\n\tliquidity\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x10yaml:\"liquidity\"\xc8\xde\x1f\x00\">\n\x17QueryTotalSharesRequest\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\"h\n\x18QueryTotalSharesResponse\x12L\n\x0ctotal_shares\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x1b\xf2\xde\x1f\x13yaml:\"total_shares\"\xc8\xde\x1f\x00\"\xab\x01\n$QueryCalcJoinPoolNoSwapSharesRequest\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12^\n\ttokens_in\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xc8\xde\x1f\x00\"\xe1\x01\n%QueryCalcJoinPoolNoSwapSharesResponse\x12t\n\ntokens_out\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBE\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x11yaml:\"tokens_out\"\xc8\xde\x1f\x00\x12\x42\n\nshares_out\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"\xc3\x01\n\x15QuerySpotPriceRequest\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x35\n\x10\x62\x61se_asset_denom\x18\x02 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"base_asset_denom\"\x12\x37\n\x11quote_asset_denom\x18\x03 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"quote_asset_denom\":\x02\x18\x01J\x04\x08\x04\x10\x05R\x0bwithSwapFee\"\x9d\x01\n\x1bQueryPoolsWithFilterRequest\x12/\n\rmin_liquidity\x18\x01 \x01(\tB\x18\xf2\xde\x1f\x14yaml:\"min_liquidity\"\x12\x11\n\tpool_type\x18\x02 \x01(\t\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8b\x01\n\x1cQueryPoolsWithFilterResponse\x12.\n\x05pools\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyB\t\xca\xb4-\x05PoolI\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"G\n\x16QuerySpotPriceResponse\x12)\n\nspot_price\x18\x01 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"spot_price\":\x02\x18\x01\"\xde\x01\n\x1dQuerySwapExactAmountInRequest\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12%\n\x08token_in\x18\x03 \x01(\tB\x13\xf2\xde\x1f\x0fyaml:\"token_in\"\x12N\n\x06routes\x18\x04 \x03(\x0b\x32\'.osmosis.gamm.v1beta1.SwapAmountInRouteB\x15\xf2\xde\x1f\ryaml:\"routes\"\xc8\xde\x1f\x00\"\x85\x01\n\x1eQuerySwapExactAmountInResponse\x12\x63\n\x10token_out_amount\x18\x01 \x01(\tBI\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:\"token_out_amount\"\xc8\xde\x1f\x00\"\xe2\x01\n\x1eQuerySwapExactAmountOutRequest\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12O\n\x06routes\x18\x03 \x03(\x0b\x32(.osmosis.gamm.v1beta1.SwapAmountOutRouteB\x15\xf2\xde\x1f\ryaml:\"routes\"\xc8\xde\x1f\x00\x12\'\n\ttoken_out\x18\x04 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"token_out\"\"\x84\x01\n\x1fQuerySwapExactAmountOutResponse\x12\x61\n\x0ftoken_in_amount\x18\x01 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"token_in_amount\"\xc8\xde\x1f\x00\"\x1c\n\x1aQueryTotalLiquidityRequest\"\x91\x01\n\x1bQueryTotalLiquidityResponse\x12r\n\tliquidity\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x10yaml:\"liquidity\"\xc8\xde\x1f\x00\x32\xaa\x14\n\x05Query\x12\x7f\n\x05Pools\x12\'.osmosis.gamm.v1beta1.QueryPoolsRequest\x1a(.osmosis.gamm.v1beta1.QueryPoolsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/osmosis/gamm/v1beta1/pools\x12\x8c\x01\n\x08NumPools\x12*.osmosis.gamm.v1beta1.QueryNumPoolsRequest\x1a+.osmosis.gamm.v1beta1.QueryNumPoolsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/osmosis/gamm/v1beta1/num_pools\x12\xa4\x01\n\x0eTotalLiquidity\x12\x30.osmosis.gamm.v1beta1.QueryTotalLiquidityRequest\x1a\x31.osmosis.gamm.v1beta1.QueryTotalLiquidityResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/osmosis/gamm/v1beta1/total_liquidity\x12\xa6\x01\n\x0fPoolsWithFilter\x12\x31.osmosis.gamm.v1beta1.QueryPoolsWithFilterRequest\x1a\x32.osmosis.gamm.v1beta1.QueryPoolsWithFilterResponse\",\x82\xd3\xe4\x93\x02&\x12$/osmosis/gamm/v1beta1/filtered_pools\x12\x86\x01\n\x04Pool\x12&.osmosis.gamm.v1beta1.QueryPoolRequest\x1a\'.osmosis.gamm.v1beta1.QueryPoolResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/osmosis/gamm/v1beta1/pools/{pool_id}\x12\x96\x01\n\x08PoolType\x12*.osmosis.gamm.v1beta1.QueryPoolTypeRequest\x1a+.osmosis.gamm.v1beta1.QueryPoolTypeResponse\"1\x82\xd3\xe4\x93\x02+\x12)/osmosis/gamm/v1beta1/pool_type/{pool_id}\x12\x95\x01\n\x18\x43\x61lcJoinPoolNoSwapShares\x12:.osmosis.gamm.v1beta1.QueryCalcJoinPoolNoSwapSharesRequest\x1a;.osmosis.gamm.v1beta1.QueryCalcJoinPoolNoSwapSharesResponse\"\x00\x12\xc3\x01\n\x12\x43\x61lcJoinPoolShares\x12\x34.osmosis.gamm.v1beta1.QueryCalcJoinPoolSharesRequest\x1a\x35.osmosis.gamm.v1beta1.QueryCalcJoinPoolSharesResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/osmosis/gamm/v1beta1/pools/{pool_id}/join_swap_exact_in\x12\xe5\x01\n\x1b\x43\x61lcExitPoolCoinsFromShares\x12=.osmosis.gamm.v1beta1.QueryCalcExitPoolCoinsFromSharesRequest\x1a>.osmosis.gamm.v1beta1.QueryCalcExitPoolCoinsFromSharesResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/osmosis/gamm/v1beta1/pools/{pool_id}/exit_swap_share_amount_in\x12\x9f\x01\n\nPoolParams\x12,.osmosis.gamm.v1beta1.QueryPoolParamsRequest\x1a-.osmosis.gamm.v1beta1.QueryPoolParamsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/osmosis/gamm/v1beta1/pools/{pool_id}/params\x12\xc5\x01\n\x12TotalPoolLiquidity\x12\x34.osmosis.gamm.v1beta1.QueryTotalPoolLiquidityRequest\x1a\x35.osmosis.gamm.v1beta1.QueryTotalPoolLiquidityResponse\"B\x82\xd3\xe4\x93\x02<\x12:/osmosis/gamm/v1beta1/pools/{pool_id}/total_pool_liquidity\x12\xa8\x01\n\x0bTotalShares\x12-.osmosis.gamm.v1beta1.QueryTotalSharesRequest\x1a..osmosis.gamm.v1beta1.QueryTotalSharesResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/osmosis/gamm/v1beta1/pools/{pool_id}/total_shares\x12\x9f\x01\n\tSpotPrice\x12+.osmosis.gamm.v1beta1.QuerySpotPriceRequest\x1a,.osmosis.gamm.v1beta1.QuerySpotPriceResponse\"7\x88\x02\x01\x82\xd3\xe4\x93\x02.\x12,/osmosis/gamm/v1beta1/pools/{pool_id}/prices\x12\xcd\x01\n\x19\x45stimateSwapExactAmountIn\x12\x33.osmosis.gamm.v1beta1.QuerySwapExactAmountInRequest\x1a\x34.osmosis.gamm.v1beta1.QuerySwapExactAmountInResponse\"E\x82\xd3\xe4\x93\x02?\x12=/osmosis/gamm/v1beta1/{pool_id}/estimate/swap_exact_amount_in\x12\xd1\x01\n\x1a\x45stimateSwapExactAmountOut\x12\x34.osmosis.gamm.v1beta1.QuerySwapExactAmountOutRequest\x1a\x35.osmosis.gamm.v1beta1.QuerySwapExactAmountOutResponse\"F\x82\xd3\xe4\x93\x02@\x12>/osmosis/gamm/v1beta1/{pool_id}/estimate/swap_exact_amount_outB2Z0github.com/osmosis-labs/osmosis/v14/x/gamm/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.gamm.v1beta1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/osmosis-labs/osmosis/v14/x/gamm/types'
  _QUERYPOOLREQUEST.fields_by_name['pool_id']._options = None
  _QUERYPOOLREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYPOOLRESPONSE.fields_by_name['pool']._options = None
  _QUERYPOOLRESPONSE.fields_by_name['pool']._serialized_options = b'\312\264-\005PoolI'
  _QUERYPOOLSRESPONSE.fields_by_name['pools']._options = None
  _QUERYPOOLSRESPONSE.fields_by_name['pools']._serialized_options = b'\312\264-\005PoolI'
  _QUERYNUMPOOLSRESPONSE.fields_by_name['num_pools']._options = None
  _QUERYNUMPOOLSRESPONSE.fields_by_name['num_pools']._serialized_options = b'\362\336\037\020yaml:\"num_pools\"'
  _QUERYPOOLTYPEREQUEST.fields_by_name['pool_id']._options = None
  _QUERYPOOLTYPEREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYPOOLTYPERESPONSE.fields_by_name['pool_type']._options = None
  _QUERYPOOLTYPERESPONSE.fields_by_name['pool_type']._serialized_options = b'\362\336\037\020yaml:\"pool_type\"'
  _QUERYCALCJOINPOOLSHARESREQUEST.fields_by_name['pool_id']._options = None
  _QUERYCALCJOINPOOLSHARESREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYCALCJOINPOOLSHARESREQUEST.fields_by_name['tokens_in']._options = None
  _QUERYCALCJOINPOOLSHARESREQUEST.fields_by_name['tokens_in']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\310\336\037\000'
  _QUERYCALCJOINPOOLSHARESRESPONSE.fields_by_name['share_out_amount']._options = None
  _QUERYCALCJOINPOOLSHARESRESPONSE.fields_by_name['share_out_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\027yaml:\"share_out_amount\"\310\336\037\000'
  _QUERYCALCJOINPOOLSHARESRESPONSE.fields_by_name['tokens_out']._options = None
  _QUERYCALCJOINPOOLSHARESRESPONSE.fields_by_name['tokens_out']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\310\336\037\000'
  _QUERYCALCEXITPOOLCOINSFROMSHARESREQUEST.fields_by_name['share_in_amount']._options = None
  _QUERYCALCEXITPOOLCOINSFROMSHARESREQUEST.fields_by_name['share_in_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _QUERYCALCEXITPOOLCOINSFROMSHARESRESPONSE.fields_by_name['tokens_out']._options = None
  _QUERYCALCEXITPOOLCOINSFROMSHARESRESPONSE.fields_by_name['tokens_out']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\310\336\037\000'
  _QUERYPOOLPARAMSREQUEST.fields_by_name['pool_id']._options = None
  _QUERYPOOLPARAMSREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYTOTALPOOLLIQUIDITYREQUEST.fields_by_name['pool_id']._options = None
  _QUERYTOTALPOOLLIQUIDITYREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYTOTALPOOLLIQUIDITYRESPONSE.fields_by_name['liquidity']._options = None
  _QUERYTOTALPOOLLIQUIDITYRESPONSE.fields_by_name['liquidity']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\020yaml:\"liquidity\"\310\336\037\000'
  _QUERYTOTALSHARESREQUEST.fields_by_name['pool_id']._options = None
  _QUERYTOTALSHARESREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYTOTALSHARESRESPONSE.fields_by_name['total_shares']._options = None
  _QUERYTOTALSHARESRESPONSE.fields_by_name['total_shares']._serialized_options = b'\362\336\037\023yaml:\"total_shares\"\310\336\037\000'
  _QUERYCALCJOINPOOLNOSWAPSHARESREQUEST.fields_by_name['pool_id']._options = None
  _QUERYCALCJOINPOOLNOSWAPSHARESREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYCALCJOINPOOLNOSWAPSHARESREQUEST.fields_by_name['tokens_in']._options = None
  _QUERYCALCJOINPOOLNOSWAPSHARESREQUEST.fields_by_name['tokens_in']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\310\336\037\000'
  _QUERYCALCJOINPOOLNOSWAPSHARESRESPONSE.fields_by_name['tokens_out']._options = None
  _QUERYCALCJOINPOOLNOSWAPSHARESRESPONSE.fields_by_name['tokens_out']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\021yaml:\"tokens_out\"\310\336\037\000'
  _QUERYCALCJOINPOOLNOSWAPSHARESRESPONSE.fields_by_name['shares_out']._options = None
  _QUERYCALCJOINPOOLNOSWAPSHARESRESPONSE.fields_by_name['shares_out']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _QUERYSPOTPRICEREQUEST.fields_by_name['pool_id']._options = None
  _QUERYSPOTPRICEREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYSPOTPRICEREQUEST.fields_by_name['base_asset_denom']._options = None
  _QUERYSPOTPRICEREQUEST.fields_by_name['base_asset_denom']._serialized_options = b'\362\336\037\027yaml:\"base_asset_denom\"'
  _QUERYSPOTPRICEREQUEST.fields_by_name['quote_asset_denom']._options = None
  _QUERYSPOTPRICEREQUEST.fields_by_name['quote_asset_denom']._serialized_options = b'\362\336\037\030yaml:\"quote_asset_denom\"'
  _QUERYSPOTPRICEREQUEST._options = None
  _QUERYSPOTPRICEREQUEST._serialized_options = b'\030\001'
  _QUERYPOOLSWITHFILTERREQUEST.fields_by_name['min_liquidity']._options = None
  _QUERYPOOLSWITHFILTERREQUEST.fields_by_name['min_liquidity']._serialized_options = b'\362\336\037\024yaml:\"min_liquidity\"'
  _QUERYPOOLSWITHFILTERRESPONSE.fields_by_name['pools']._options = None
  _QUERYPOOLSWITHFILTERRESPONSE.fields_by_name['pools']._serialized_options = b'\312\264-\005PoolI'
  _QUERYSPOTPRICERESPONSE.fields_by_name['spot_price']._options = None
  _QUERYSPOTPRICERESPONSE.fields_by_name['spot_price']._serialized_options = b'\362\336\037\021yaml:\"spot_price\"'
  _QUERYSPOTPRICERESPONSE._options = None
  _QUERYSPOTPRICERESPONSE._serialized_options = b'\030\001'
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['sender']._options = None
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['pool_id']._options = None
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['token_in']._options = None
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['token_in']._serialized_options = b'\362\336\037\017yaml:\"token_in\"'
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['routes']._options = None
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['routes']._serialized_options = b'\362\336\037\ryaml:\"routes\"\310\336\037\000'
  _QUERYSWAPEXACTAMOUNTINRESPONSE.fields_by_name['token_out_amount']._options = None
  _QUERYSWAPEXACTAMOUNTINRESPONSE.fields_by_name['token_out_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\027yaml:\"token_out_amount\"\310\336\037\000'
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['sender']._options = None
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['pool_id']._options = None
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['routes']._options = None
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['routes']._serialized_options = b'\362\336\037\ryaml:\"routes\"\310\336\037\000'
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['token_out']._options = None
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['token_out']._serialized_options = b'\362\336\037\020yaml:\"token_out\"'
  _QUERYSWAPEXACTAMOUNTOUTRESPONSE.fields_by_name['token_in_amount']._options = None
  _QUERYSWAPEXACTAMOUNTOUTRESPONSE.fields_by_name['token_in_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"token_in_amount\"\310\336\037\000'
  _QUERYTOTALLIQUIDITYRESPONSE.fields_by_name['liquidity']._options = None
  _QUERYTOTALLIQUIDITYRESPONSE.fields_by_name['liquidity']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\020yaml:\"liquidity\"\310\336\037\000'
  _QUERY.methods_by_name['Pools']._options = None
  _QUERY.methods_by_name['Pools']._serialized_options = b'\202\323\344\223\002\035\022\033/osmosis/gamm/v1beta1/pools'
  _QUERY.methods_by_name['NumPools']._options = None
  _QUERY.methods_by_name['NumPools']._serialized_options = b'\202\323\344\223\002!\022\037/osmosis/gamm/v1beta1/num_pools'
  _QUERY.methods_by_name['TotalLiquidity']._options = None
  _QUERY.methods_by_name['TotalLiquidity']._serialized_options = b'\202\323\344\223\002\'\022%/osmosis/gamm/v1beta1/total_liquidity'
  _QUERY.methods_by_name['PoolsWithFilter']._options = None
  _QUERY.methods_by_name['PoolsWithFilter']._serialized_options = b'\202\323\344\223\002&\022$/osmosis/gamm/v1beta1/filtered_pools'
  _QUERY.methods_by_name['Pool']._options = None
  _QUERY.methods_by_name['Pool']._serialized_options = b'\202\323\344\223\002\'\022%/osmosis/gamm/v1beta1/pools/{pool_id}'
  _QUERY.methods_by_name['PoolType']._options = None
  _QUERY.methods_by_name['PoolType']._serialized_options = b'\202\323\344\223\002+\022)/osmosis/gamm/v1beta1/pool_type/{pool_id}'
  _QUERY.methods_by_name['CalcJoinPoolShares']._options = None
  _QUERY.methods_by_name['CalcJoinPoolShares']._serialized_options = b'\202\323\344\223\002:\0228/osmosis/gamm/v1beta1/pools/{pool_id}/join_swap_exact_in'
  _QUERY.methods_by_name['CalcExitPoolCoinsFromShares']._options = None
  _QUERY.methods_by_name['CalcExitPoolCoinsFromShares']._serialized_options = b'\202\323\344\223\002A\022?/osmosis/gamm/v1beta1/pools/{pool_id}/exit_swap_share_amount_in'
  _QUERY.methods_by_name['PoolParams']._options = None
  _QUERY.methods_by_name['PoolParams']._serialized_options = b'\202\323\344\223\002.\022,/osmosis/gamm/v1beta1/pools/{pool_id}/params'
  _QUERY.methods_by_name['TotalPoolLiquidity']._options = None
  _QUERY.methods_by_name['TotalPoolLiquidity']._serialized_options = b'\202\323\344\223\002<\022:/osmosis/gamm/v1beta1/pools/{pool_id}/total_pool_liquidity'
  _QUERY.methods_by_name['TotalShares']._options = None
  _QUERY.methods_by_name['TotalShares']._serialized_options = b'\202\323\344\223\0024\0222/osmosis/gamm/v1beta1/pools/{pool_id}/total_shares'
  _QUERY.methods_by_name['SpotPrice']._options = None
  _QUERY.methods_by_name['SpotPrice']._serialized_options = b'\210\002\001\202\323\344\223\002.\022,/osmosis/gamm/v1beta1/pools/{pool_id}/prices'
  _QUERY.methods_by_name['EstimateSwapExactAmountIn']._options = None
  _QUERY.methods_by_name['EstimateSwapExactAmountIn']._serialized_options = b'\202\323\344\223\002?\022=/osmosis/gamm/v1beta1/{pool_id}/estimate/swap_exact_amount_in'
  _QUERY.methods_by_name['EstimateSwapExactAmountOut']._options = None
  _QUERY.methods_by_name['EstimateSwapExactAmountOut']._serialized_options = b'\202\323\344\223\002@\022>/osmosis/gamm/v1beta1/{pool_id}/estimate/swap_exact_amount_out'
  _QUERYPOOLREQUEST._serialized_start=271
  _QUERYPOOLREQUEST._serialized_end=326
  _QUERYPOOLRESPONSE._serialized_start=328
  _QUERYPOOLRESPONSE._serialized_end=394
  _QUERYPOOLSREQUEST._serialized_start=396
  _QUERYPOOLSREQUEST._serialized_end=475
  _QUERYPOOLSRESPONSE._serialized_start=478
  _QUERYPOOLSRESPONSE._serialized_end=607
  _QUERYNUMPOOLSREQUEST._serialized_start=609
  _QUERYNUMPOOLSREQUEST._serialized_end=631
  _QUERYNUMPOOLSRESPONSE._serialized_start=633
  _QUERYNUMPOOLSRESPONSE._serialized_end=697
  _QUERYPOOLTYPEREQUEST._serialized_start=699
  _QUERYPOOLTYPEREQUEST._serialized_end=758
  _QUERYPOOLTYPERESPONSE._serialized_start=760
  _QUERYPOOLTYPERESPONSE._serialized_end=824
  _QUERYCALCJOINPOOLSHARESREQUEST._serialized_start=827
  _QUERYCALCJOINPOOLSHARESREQUEST._serialized_end=992
  _QUERYCALCJOINPOOLSHARESRESPONSE._serialized_start=995
  _QUERYCALCJOINPOOLSHARESRESPONSE._serialized_end=1226
  _QUERYCALCEXITPOOLCOINSFROMSHARESREQUEST._serialized_start=1229
  _QUERYCALCEXITPOOLCOINSFROMSHARESREQUEST._serialized_end=1360
  _QUERYCALCEXITPOOLCOINSFROMSHARESRESPONSE._serialized_start=1363
  _QUERYCALCEXITPOOLCOINSFROMSHARESRESPONSE._serialized_end=1502
  _QUERYPOOLPARAMSREQUEST._serialized_start=1504
  _QUERYPOOLPARAMSREQUEST._serialized_end=1565
  _QUERYPOOLPARAMSRESPONSE._serialized_start=1567
  _QUERYPOOLPARAMSRESPONSE._serialized_end=1630
  _QUERYTOTALPOOLLIQUIDITYREQUEST._serialized_start=1632
  _QUERYTOTALPOOLLIQUIDITYREQUEST._serialized_end=1701
  _QUERYTOTALPOOLLIQUIDITYRESPONSE._serialized_start=1704
  _QUERYTOTALPOOLLIQUIDITYRESPONSE._serialized_end=1853
  _QUERYTOTALSHARESREQUEST._serialized_start=1855
  _QUERYTOTALSHARESREQUEST._serialized_end=1917
  _QUERYTOTALSHARESRESPONSE._serialized_start=1919
  _QUERYTOTALSHARESRESPONSE._serialized_end=2023
  _QUERYCALCJOINPOOLNOSWAPSHARESREQUEST._serialized_start=2026
  _QUERYCALCJOINPOOLNOSWAPSHARESREQUEST._serialized_end=2197
  _QUERYCALCJOINPOOLNOSWAPSHARESRESPONSE._serialized_start=2200
  _QUERYCALCJOINPOOLNOSWAPSHARESRESPONSE._serialized_end=2425
  _QUERYSPOTPRICEREQUEST._serialized_start=2428
  _QUERYSPOTPRICEREQUEST._serialized_end=2623
  _QUERYPOOLSWITHFILTERREQUEST._serialized_start=2626
  _QUERYPOOLSWITHFILTERREQUEST._serialized_end=2783
  _QUERYPOOLSWITHFILTERRESPONSE._serialized_start=2786
  _QUERYPOOLSWITHFILTERRESPONSE._serialized_end=2925
  _QUERYSPOTPRICERESPONSE._serialized_start=2927
  _QUERYSPOTPRICERESPONSE._serialized_end=2998
  _QUERYSWAPEXACTAMOUNTINREQUEST._serialized_start=3001
  _QUERYSWAPEXACTAMOUNTINREQUEST._serialized_end=3223
  _QUERYSWAPEXACTAMOUNTINRESPONSE._serialized_start=3226
  _QUERYSWAPEXACTAMOUNTINRESPONSE._serialized_end=3359
  _QUERYSWAPEXACTAMOUNTOUTREQUEST._serialized_start=3362
  _QUERYSWAPEXACTAMOUNTOUTREQUEST._serialized_end=3588
  _QUERYSWAPEXACTAMOUNTOUTRESPONSE._serialized_start=3591
  _QUERYSWAPEXACTAMOUNTOUTRESPONSE._serialized_end=3723
  _QUERYTOTALLIQUIDITYREQUEST._serialized_start=3725
  _QUERYTOTALLIQUIDITYREQUEST._serialized_end=3753
  _QUERYTOTALLIQUIDITYRESPONSE._serialized_start=3756
  _QUERYTOTALLIQUIDITYRESPONSE._serialized_end=3901
  _QUERY._serialized_start=3904
  _QUERY._serialized_end=6506
# @@protoc_insertion_point(module_scope)
