"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.superfluid.superfluid_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SetSuperfluidAssetsProposal(google.protobuf.message.Message):
    """SetSuperfluidAssetsProposal is a gov Content type to update the superfluid
    assets
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ASSETS_FIELD_NUMBER: builtins.int
    title: builtins.str
    description: builtins.str
    @property
    def assets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.superfluid.superfluid_pb2.SuperfluidAsset]: ...
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
        assets: collections.abc.Iterable[osmosis.superfluid.superfluid_pb2.SuperfluidAsset] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["assets", b"assets", "description", b"description", "title", b"title"]) -> None: ...

global___SetSuperfluidAssetsProposal = SetSuperfluidAssetsProposal

@typing_extensions.final
class RemoveSuperfluidAssetsProposal(google.protobuf.message.Message):
    """RemoveSuperfluidAssetsProposal is a gov Content type to remove the superfluid
    assets by denom
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SUPERFLUID_ASSET_DENOMS_FIELD_NUMBER: builtins.int
    title: builtins.str
    description: builtins.str
    @property
    def superfluid_asset_denoms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
        superfluid_asset_denoms: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "superfluid_asset_denoms", b"superfluid_asset_denoms", "title", b"title"]) -> None: ...

global___RemoveSuperfluidAssetsProposal = RemoveSuperfluidAssetsProposal

@typing_extensions.final
class UpdateUnpoolWhiteListProposal(google.protobuf.message.Message):
    """UpdateUnpoolWhiteListProposal is a gov Content type to update the
    allowed list of pool ids.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    IDS_FIELD_NUMBER: builtins.int
    IS_OVERWRITE_FIELD_NUMBER: builtins.int
    title: builtins.str
    description: builtins.str
    @property
    def ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    is_overwrite: builtins.bool
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
        ids: collections.abc.Iterable[builtins.int] | None = ...,
        is_overwrite: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "ids", b"ids", "is_overwrite", b"is_overwrite", "title", b"title"]) -> None: ...

global___UpdateUnpoolWhiteListProposal = UpdateUnpoolWhiteListProposal
