"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DenomAuthorityMetadata(google.protobuf.message.Message):
    """DenomAuthorityMetadata specifies metadata for addresses that have specific
    capabilities over a token factory denom. Right now there is only one Admin
    permission, but is planned to be extended to the future.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMIN_FIELD_NUMBER: builtins.int
    admin: builtins.str
    """Can be empty for no admin, or a valid osmosis address"""
    def __init__(
        self,
        *,
        admin: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin", b"admin"]) -> None: ...

global___DenomAuthorityMetadata = DenomAuthorityMetadata
