"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.incentives.gauge_pb2
import osmosis.pool_incentives.v1beta1.incentives_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QueryGaugeIdsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id"]) -> None: ...

global___QueryGaugeIdsRequest = QueryGaugeIdsRequest

@typing_extensions.final
class QueryGaugeIdsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class GaugeIdWithDuration(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        GAUGE_ID_FIELD_NUMBER: builtins.int
        DURATION_FIELD_NUMBER: builtins.int
        GAUGE_INCENTIVE_PERCENTAGE_FIELD_NUMBER: builtins.int
        gauge_id: builtins.int
        @property
        def duration(self) -> google.protobuf.duration_pb2.Duration: ...
        gauge_incentive_percentage: builtins.str
        def __init__(
            self,
            *,
            gauge_id: builtins.int = ...,
            duration: google.protobuf.duration_pb2.Duration | None = ...,
            gauge_incentive_percentage: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration", "gauge_id", b"gauge_id", "gauge_incentive_percentage", b"gauge_incentive_percentage"]) -> None: ...

    GAUGE_IDS_WITH_DURATION_FIELD_NUMBER: builtins.int
    @property
    def gauge_ids_with_duration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___QueryGaugeIdsResponse.GaugeIdWithDuration]: ...
    def __init__(
        self,
        *,
        gauge_ids_with_duration: collections.abc.Iterable[global___QueryGaugeIdsResponse.GaugeIdWithDuration] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gauge_ids_with_duration", b"gauge_ids_with_duration"]) -> None: ...

global___QueryGaugeIdsResponse = QueryGaugeIdsResponse

@typing_extensions.final
class QueryDistrInfoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryDistrInfoRequest = QueryDistrInfoRequest

@typing_extensions.final
class QueryDistrInfoResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISTR_INFO_FIELD_NUMBER: builtins.int
    @property
    def distr_info(self) -> osmosis.pool_incentives.v1beta1.incentives_pb2.DistrInfo: ...
    def __init__(
        self,
        *,
        distr_info: osmosis.pool_incentives.v1beta1.incentives_pb2.DistrInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["distr_info", b"distr_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["distr_info", b"distr_info"]) -> None: ...

global___QueryDistrInfoResponse = QueryDistrInfoResponse

@typing_extensions.final
class QueryParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryParamsRequest = QueryParamsRequest

@typing_extensions.final
class QueryParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> osmosis.pool_incentives.v1beta1.incentives_pb2.Params: ...
    def __init__(
        self,
        *,
        params: osmosis.pool_incentives.v1beta1.incentives_pb2.Params | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___QueryParamsResponse = QueryParamsResponse

@typing_extensions.final
class QueryLockableDurationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryLockableDurationsRequest = QueryLockableDurationsRequest

@typing_extensions.final
class QueryLockableDurationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCKABLE_DURATIONS_FIELD_NUMBER: builtins.int
    @property
    def lockable_durations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.duration_pb2.Duration]: ...
    def __init__(
        self,
        *,
        lockable_durations: collections.abc.Iterable[google.protobuf.duration_pb2.Duration] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lockable_durations", b"lockable_durations"]) -> None: ...

global___QueryLockableDurationsResponse = QueryLockableDurationsResponse

@typing_extensions.final
class QueryIncentivizedPoolsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryIncentivizedPoolsRequest = QueryIncentivizedPoolsRequest

@typing_extensions.final
class IncentivizedPool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    LOCKABLE_DURATION_FIELD_NUMBER: builtins.int
    GAUGE_ID_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    @property
    def lockable_duration(self) -> google.protobuf.duration_pb2.Duration: ...
    gauge_id: builtins.int
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        lockable_duration: google.protobuf.duration_pb2.Duration | None = ...,
        gauge_id: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["lockable_duration", b"lockable_duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gauge_id", b"gauge_id", "lockable_duration", b"lockable_duration", "pool_id", b"pool_id"]) -> None: ...

global___IncentivizedPool = IncentivizedPool

@typing_extensions.final
class QueryIncentivizedPoolsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INCENTIVIZED_POOLS_FIELD_NUMBER: builtins.int
    @property
    def incentivized_pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IncentivizedPool]: ...
    def __init__(
        self,
        *,
        incentivized_pools: collections.abc.Iterable[global___IncentivizedPool] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["incentivized_pools", b"incentivized_pools"]) -> None: ...

global___QueryIncentivizedPoolsResponse = QueryIncentivizedPoolsResponse

@typing_extensions.final
class QueryExternalIncentiveGaugesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryExternalIncentiveGaugesRequest = QueryExternalIncentiveGaugesRequest

@typing_extensions.final
class QueryExternalIncentiveGaugesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.incentives.gauge_pb2.Gauge]: ...
    def __init__(
        self,
        *,
        data: collections.abc.Iterable[osmosis.incentives.gauge_pb2.Gauge] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data"]) -> None: ...

global___QueryExternalIncentiveGaugesResponse = QueryExternalIncentiveGaugesResponse
