"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Params(google.protobuf.message.Message):
    """Params holds parameters for the incentives module"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_CREATION_FEE_FIELD_NUMBER: builtins.int
    @property
    def pool_creation_fee(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        pool_creation_fee: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_creation_fee", b"pool_creation_fee"]) -> None: ...

global___Params = Params

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the gamm module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOLS_FIELD_NUMBER: builtins.int
    NEXT_POOL_NUMBER_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]: ...
    next_pool_number: builtins.int
    """will be renamed to next_pool_id in an upcoming version"""
    @property
    def params(self) -> global___Params: ...
    def __init__(
        self,
        *,
        pools: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
        next_pool_number: builtins.int = ...,
        params: global___Params | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_pool_number", b"next_pool_number", "params", b"params", "pools", b"pools"]) -> None: ...

global___GenesisState = GenesisState
