"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.ibc_rate_limit.v1beta1.query_pb2

class QueryStub:
    """Query defines the gRPC querier service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    Params: grpc.UnaryUnaryMultiCallable[
        osmosis.ibc_rate_limit.v1beta1.query_pb2.ParamsRequest,
        osmosis.ibc_rate_limit.v1beta1.query_pb2.ParamsResponse,
    ]
    """Params defines a gRPC query method that returns the ibc-rate-limit module's
    parameters.
    """

class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service."""

    @abc.abstractmethod
    def Params(
        self,
        request: osmosis.ibc_rate_limit.v1beta1.query_pb2.ParamsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.ibc_rate_limit.v1beta1.query_pb2.ParamsResponse:
        """Params defines a gRPC query method that returns the ibc-rate-limit module's
        parameters.
        """

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...
