"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Params(google.protobuf.message.Message):
    """Params holds parameters for the superfluid module"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MINIMUM_RISK_FACTOR_FIELD_NUMBER: builtins.int
    minimum_risk_factor: builtins.str
    """minimum_risk_factor is to be cut on OSMO equivalent value of lp tokens for
    superfluid staking, default: 5%. The minimum risk factor works
    to counter-balance the staked amount on chain's exposure to various asset
    volatilities, and have base staking be 'resistant' to volatility.
    """
    def __init__(
        self,
        *,
        minimum_risk_factor: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["minimum_risk_factor", b"minimum_risk_factor"]) -> None: ...

global___Params = Params
