"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Protocol Buffers for Go with Gadgets

Copyright (c) 2013, The GoGo Authors. All rights reserved.
http://github.com/gogo/protobuf

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

    * Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above
copyright notice, this list of conditions and the following disclaimer
in the documentation and/or other materials provided with the
distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.extension_dict

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

GOPROTO_ENUM_PREFIX_FIELD_NUMBER: builtins.int
GOPROTO_ENUM_STRINGER_FIELD_NUMBER: builtins.int
ENUM_STRINGER_FIELD_NUMBER: builtins.int
ENUM_CUSTOMNAME_FIELD_NUMBER: builtins.int
ENUMDECL_FIELD_NUMBER: builtins.int
ENUMVALUE_CUSTOMNAME_FIELD_NUMBER: builtins.int
GOPROTO_GETTERS_ALL_FIELD_NUMBER: builtins.int
GOPROTO_ENUM_PREFIX_ALL_FIELD_NUMBER: builtins.int
GOPROTO_STRINGER_ALL_FIELD_NUMBER: builtins.int
VERBOSE_EQUAL_ALL_FIELD_NUMBER: builtins.int
FACE_ALL_FIELD_NUMBER: builtins.int
GOSTRING_ALL_FIELD_NUMBER: builtins.int
POPULATE_ALL_FIELD_NUMBER: builtins.int
STRINGER_ALL_FIELD_NUMBER: builtins.int
ONLYONE_ALL_FIELD_NUMBER: builtins.int
EQUAL_ALL_FIELD_NUMBER: builtins.int
DESCRIPTION_ALL_FIELD_NUMBER: builtins.int
TESTGEN_ALL_FIELD_NUMBER: builtins.int
BENCHGEN_ALL_FIELD_NUMBER: builtins.int
MARSHALER_ALL_FIELD_NUMBER: builtins.int
UNMARSHALER_ALL_FIELD_NUMBER: builtins.int
STABLE_MARSHALER_ALL_FIELD_NUMBER: builtins.int
SIZER_ALL_FIELD_NUMBER: builtins.int
GOPROTO_ENUM_STRINGER_ALL_FIELD_NUMBER: builtins.int
ENUM_STRINGER_ALL_FIELD_NUMBER: builtins.int
UNSAFE_MARSHALER_ALL_FIELD_NUMBER: builtins.int
UNSAFE_UNMARSHALER_ALL_FIELD_NUMBER: builtins.int
GOPROTO_EXTENSIONS_MAP_ALL_FIELD_NUMBER: builtins.int
GOPROTO_UNRECOGNIZED_ALL_FIELD_NUMBER: builtins.int
GOGOPROTO_IMPORT_FIELD_NUMBER: builtins.int
PROTOSIZER_ALL_FIELD_NUMBER: builtins.int
COMPARE_ALL_FIELD_NUMBER: builtins.int
TYPEDECL_ALL_FIELD_NUMBER: builtins.int
ENUMDECL_ALL_FIELD_NUMBER: builtins.int
GOPROTO_REGISTRATION_FIELD_NUMBER: builtins.int
MESSAGENAME_ALL_FIELD_NUMBER: builtins.int
GOPROTO_SIZECACHE_ALL_FIELD_NUMBER: builtins.int
GOPROTO_UNKEYED_ALL_FIELD_NUMBER: builtins.int
GOPROTO_GETTERS_FIELD_NUMBER: builtins.int
GOPROTO_STRINGER_FIELD_NUMBER: builtins.int
VERBOSE_EQUAL_FIELD_NUMBER: builtins.int
FACE_FIELD_NUMBER: builtins.int
GOSTRING_FIELD_NUMBER: builtins.int
POPULATE_FIELD_NUMBER: builtins.int
STRINGER_FIELD_NUMBER: builtins.int
ONLYONE_FIELD_NUMBER: builtins.int
EQUAL_FIELD_NUMBER: builtins.int
DESCRIPTION_FIELD_NUMBER: builtins.int
TESTGEN_FIELD_NUMBER: builtins.int
BENCHGEN_FIELD_NUMBER: builtins.int
MARSHALER_FIELD_NUMBER: builtins.int
UNMARSHALER_FIELD_NUMBER: builtins.int
STABLE_MARSHALER_FIELD_NUMBER: builtins.int
SIZER_FIELD_NUMBER: builtins.int
UNSAFE_MARSHALER_FIELD_NUMBER: builtins.int
UNSAFE_UNMARSHALER_FIELD_NUMBER: builtins.int
GOPROTO_EXTENSIONS_MAP_FIELD_NUMBER: builtins.int
GOPROTO_UNRECOGNIZED_FIELD_NUMBER: builtins.int
PROTOSIZER_FIELD_NUMBER: builtins.int
COMPARE_FIELD_NUMBER: builtins.int
TYPEDECL_FIELD_NUMBER: builtins.int
MESSAGENAME_FIELD_NUMBER: builtins.int
GOPROTO_SIZECACHE_FIELD_NUMBER: builtins.int
GOPROTO_UNKEYED_FIELD_NUMBER: builtins.int
NULLABLE_FIELD_NUMBER: builtins.int
EMBED_FIELD_NUMBER: builtins.int
CUSTOMTYPE_FIELD_NUMBER: builtins.int
CUSTOMNAME_FIELD_NUMBER: builtins.int
JSONTAG_FIELD_NUMBER: builtins.int
MORETAGS_FIELD_NUMBER: builtins.int
CASTTYPE_FIELD_NUMBER: builtins.int
CASTKEY_FIELD_NUMBER: builtins.int
CASTVALUE_FIELD_NUMBER: builtins.int
STDTIME_FIELD_NUMBER: builtins.int
STDDURATION_FIELD_NUMBER: builtins.int
WKTPOINTER_FIELD_NUMBER: builtins.int
CASTREPEATED_FIELD_NUMBER: builtins.int
goproto_enum_prefix: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.EnumOptions, builtins.bool]
goproto_enum_stringer: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.EnumOptions, builtins.bool]
enum_stringer: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.EnumOptions, builtins.bool]
enum_customname: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.EnumOptions, builtins.str]
enumdecl: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.EnumOptions, builtins.bool]
enumvalue_customname: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.EnumValueOptions, builtins.str]
goproto_getters_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_enum_prefix_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_stringer_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
verbose_equal_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
face_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
gostring_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
populate_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
stringer_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
onlyone_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
equal_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
description_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
testgen_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
benchgen_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
marshaler_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
unmarshaler_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
stable_marshaler_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
sizer_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_enum_stringer_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
enum_stringer_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
unsafe_marshaler_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
unsafe_unmarshaler_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_extensions_map_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_unrecognized_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
gogoproto_import: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
protosizer_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
compare_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
typedecl_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
enumdecl_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_registration: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
messagename_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_sizecache_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_unkeyed_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_getters: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
goproto_stringer: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
verbose_equal: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
face: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
gostring: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
populate: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
stringer: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
onlyone: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
equal: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
description: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
testgen: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
benchgen: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
marshaler: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
unmarshaler: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
stable_marshaler: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
sizer: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
unsafe_marshaler: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
unsafe_unmarshaler: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
goproto_extensions_map: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
goproto_unrecognized: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
protosizer: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
compare: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
typedecl: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
messagename: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
goproto_sizecache: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
goproto_unkeyed: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
nullable: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
embed: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
customtype: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
customname: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
jsontag: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
moretags: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
casttype: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
castkey: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
castvalue: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
stdtime: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
stdduration: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
wktpointer: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
castrepeated: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
