"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.txfees.v1beta1.feetoken_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the txfees module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASEDENOM_FIELD_NUMBER: builtins.int
    FEETOKENS_FIELD_NUMBER: builtins.int
    basedenom: builtins.str
    @property
    def feetokens(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.txfees.v1beta1.feetoken_pb2.FeeToken]: ...
    def __init__(
        self,
        *,
        basedenom: builtins.str = ...,
        feetokens: collections.abc.Iterable[osmosis.txfees.v1beta1.feetoken_pb2.FeeToken] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["basedenom", b"basedenom", "feetokens", b"feetokens"]) -> None: ...

global___GenesisState = GenesisState
