"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.params.v1beta1.query_pb2
import grpc

class QueryStub:
    """Query defines the gRPC querier service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    Params: grpc.UnaryUnaryMultiCallable[
        cosmos.params.v1beta1.query_pb2.QueryParamsRequest,
        cosmos.params.v1beta1.query_pb2.QueryParamsResponse,
    ]
    """Params queries a specific parameter of a module, given its subspace and
    key.
    """

class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service."""

    @abc.abstractmethod
    def Params(
        self,
        request: cosmos.params.v1beta1.query_pb2.QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.params.v1beta1.query_pb2.QueryParamsResponse:
        """Params queries a specific parameter of a module, given its subspace and
        key.
        """

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...
