# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from osmosis.gamm.pool_models.stableswap import tx_pb2 as osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2


class MsgStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateStableswapPool = channel.unary_unary(
                '/osmosis.gamm.poolmodels.stableswap.v1beta1.Msg/CreateStableswapPool',
                request_serializer=osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgCreateStableswapPool.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgCreateStableswapPoolResponse.FromString,
                )
        self.StableSwapAdjustScalingFactors = channel.unary_unary(
                '/osmosis.gamm.poolmodels.stableswap.v1beta1.Msg/StableSwapAdjustScalingFactors',
                request_serializer=osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgStableSwapAdjustScalingFactors.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgStableSwapAdjustScalingFactorsResponse.FromString,
                )


class MsgServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateStableswapPool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StableSwapAdjustScalingFactors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateStableswapPool': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateStableswapPool,
                    request_deserializer=osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgCreateStableswapPool.FromString,
                    response_serializer=osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgCreateStableswapPoolResponse.SerializeToString,
            ),
            'StableSwapAdjustScalingFactors': grpc.unary_unary_rpc_method_handler(
                    servicer.StableSwapAdjustScalingFactors,
                    request_deserializer=osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgStableSwapAdjustScalingFactors.FromString,
                    response_serializer=osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgStableSwapAdjustScalingFactorsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'osmosis.gamm.poolmodels.stableswap.v1beta1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateStableswapPool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.poolmodels.stableswap.v1beta1.Msg/CreateStableswapPool',
            osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgCreateStableswapPool.SerializeToString,
            osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgCreateStableswapPoolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StableSwapAdjustScalingFactors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.poolmodels.stableswap.v1beta1.Msg/StableSwapAdjustScalingFactors',
            osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgStableSwapAdjustScalingFactors.SerializeToString,
            osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgStableSwapAdjustScalingFactorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
