# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/gamm/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dosmosis/gamm/v1beta1/tx.proto\x12\x14osmosis.gamm.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x90\x02\n\x0bMsgJoinPool\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x62\n\x10share_out_amount\x18\x03 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"pool_amount_out\"\xc8\xde\x1f\x00\x12U\n\rtoken_in_maxs\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB#\xf2\xde\x1f\x1byaml:\"token_in_max_amounts\"\xc8\xde\x1f\x00\"\xc0\x01\n\x13MsgJoinPoolResponse\x12\x63\n\x10share_out_amount\x18\x01 \x01(\tBI\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:\"share_out_amount\"\xc8\xde\x1f\x00\x12\x44\n\x08token_in\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x17\xf2\xde\x1f\x0fyaml:\"token_in\"\xc8\xde\x1f\x00\"\x91\x02\n\x0bMsgExitPool\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x61\n\x0fshare_in_amount\x18\x03 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"share_in_amount\"\xc8\xde\x1f\x00\x12W\n\x0etoken_out_mins\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB$\xf2\xde\x1f\x1cyaml:\"token_out_min_amounts\"\xc8\xde\x1f\x00\"]\n\x13MsgExitPoolResponse\x12\x46\n\ttoken_out\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x18\xf2\xde\x1f\x10yaml:\"token_out\"\xc8\xde\x1f\x00\"m\n\x11SwapAmountInRoute\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x33\n\x0ftoken_out_denom\x18\x02 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"token_out_denom\"\"\xab\x02\n\x14MsgSwapExactAmountIn\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12=\n\x06routes\x18\x02 \x03(\x0b\x32\'.osmosis.gamm.v1beta1.SwapAmountInRouteB\x04\xc8\xde\x1f\x00\x12\x44\n\x08token_in\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x17\xf2\xde\x1f\x0fyaml:\"token_in\"\xc8\xde\x1f\x00\x12k\n\x14token_out_min_amount\x18\x04 \x01(\tBM\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1byaml:\"token_out_min_amount\"\xc8\xde\x1f\x00\"\x83\x01\n\x1cMsgSwapExactAmountInResponse\x12\x63\n\x10token_out_amount\x18\x01 \x01(\tBI\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:\"token_out_amount\"\xc8\xde\x1f\x00\"m\n\x12SwapAmountOutRoute\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x32\n\x0etoken_in_denom\x18\x02 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"token_out_denom\"\"\xad\x02\n\x15MsgSwapExactAmountOut\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12>\n\x06routes\x18\x02 \x03(\x0b\x32(.osmosis.gamm.v1beta1.SwapAmountOutRouteB\x04\xc8\xde\x1f\x00\x12i\n\x13token_in_max_amount\x18\x03 \x01(\tBL\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1ayaml:\"token_in_max_amount\"\xc8\xde\x1f\x00\x12\x46\n\ttoken_out\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x18\xf2\xde\x1f\x10yaml:\"token_out\"\xc8\xde\x1f\x00\"\x82\x01\n\x1dMsgSwapExactAmountOutResponse\x12\x61\n\x0ftoken_in_amount\x18\x01 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"token_in_amount\"\xc8\xde\x1f\x00\"\x96\x02\n\x19MsgJoinSwapExternAmountIn\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x44\n\x08token_in\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x17\xf2\xde\x1f\x0fyaml:\"token_in\"\xc8\xde\x1f\x00\x12k\n\x14share_out_min_amount\x18\x04 \x01(\tBM\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1byaml:\"share_out_min_amount\"\xc8\xde\x1f\x00\"\x88\x01\n!MsgJoinSwapExternAmountInResponse\x12\x63\n\x10share_out_amount\x18\x01 \x01(\tBI\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:\"share_out_amount\"\xc8\xde\x1f\x00\"\xe6\x02\n\x19MsgJoinSwapShareAmountOut\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x31\n\x0etoken_in_denom\x18\x03 \x01(\tB\x19\xf2\xde\x1f\x15yaml:\"token_in_denom\"\x12\x63\n\x10share_out_amount\x18\x04 \x01(\tBI\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:\"share_out_amount\"\xc8\xde\x1f\x00\x12i\n\x13token_in_max_amount\x18\x05 \x01(\tBL\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1ayaml:\"token_in_max_amount\"\xc8\xde\x1f\x00\"\x86\x01\n!MsgJoinSwapShareAmountOutResponse\x12\x61\n\x0ftoken_in_amount\x18\x01 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"token_in_amount\"\xc8\xde\x1f\x00\"\xe7\x02\n\x18MsgExitSwapShareAmountIn\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x33\n\x0ftoken_out_denom\x18\x03 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"token_out_denom\"\x12\x61\n\x0fshare_in_amount\x18\x04 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"share_in_amount\"\xc8\xde\x1f\x00\x12k\n\x14token_out_min_amount\x18\x05 \x01(\tBM\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1byaml:\"token_out_min_amount\"\xc8\xde\x1f\x00\"\x87\x01\n MsgExitSwapShareAmountInResponse\x12\x63\n\x10token_out_amount\x18\x01 \x01(\tBI\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:\"token_out_amount\"\xc8\xde\x1f\x00\"\x97\x02\n\x1aMsgExitSwapExternAmountOut\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x46\n\ttoken_out\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x18\xf2\xde\x1f\x10yaml:\"token_out\"\xc8\xde\x1f\x00\x12i\n\x13share_in_max_amount\x18\x04 \x01(\tBL\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1ayaml:\"share_in_max_amount\"\xc8\xde\x1f\x00\"\x87\x01\n\"MsgExitSwapExternAmountOutResponse\x12\x61\n\x0fshare_in_amount\x18\x01 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"share_in_amount\"\xc8\xde\x1f\x00\x32\xb9\x07\n\x03Msg\x12X\n\x08JoinPool\x12!.osmosis.gamm.v1beta1.MsgJoinPool\x1a).osmosis.gamm.v1beta1.MsgJoinPoolResponse\x12X\n\x08\x45xitPool\x12!.osmosis.gamm.v1beta1.MsgExitPool\x1a).osmosis.gamm.v1beta1.MsgExitPoolResponse\x12s\n\x11SwapExactAmountIn\x12*.osmosis.gamm.v1beta1.MsgSwapExactAmountIn\x1a\x32.osmosis.gamm.v1beta1.MsgSwapExactAmountInResponse\x12v\n\x12SwapExactAmountOut\x12+.osmosis.gamm.v1beta1.MsgSwapExactAmountOut\x1a\x33.osmosis.gamm.v1beta1.MsgSwapExactAmountOutResponse\x12\x82\x01\n\x16JoinSwapExternAmountIn\x12/.osmosis.gamm.v1beta1.MsgJoinSwapExternAmountIn\x1a\x37.osmosis.gamm.v1beta1.MsgJoinSwapExternAmountInResponse\x12\x82\x01\n\x16JoinSwapShareAmountOut\x12/.osmosis.gamm.v1beta1.MsgJoinSwapShareAmountOut\x1a\x37.osmosis.gamm.v1beta1.MsgJoinSwapShareAmountOutResponse\x12\x85\x01\n\x17\x45xitSwapExternAmountOut\x12\x30.osmosis.gamm.v1beta1.MsgExitSwapExternAmountOut\x1a\x38.osmosis.gamm.v1beta1.MsgExitSwapExternAmountOutResponse\x12\x7f\n\x15\x45xitSwapShareAmountIn\x12..osmosis.gamm.v1beta1.MsgExitSwapShareAmountIn\x1a\x36.osmosis.gamm.v1beta1.MsgExitSwapShareAmountInResponseB2Z0github.com/osmosis-labs/osmosis/v14/x/gamm/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.gamm.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/osmosis-labs/osmosis/v14/x/gamm/types'
  _MSGJOINPOOL.fields_by_name['sender']._options = None
  _MSGJOINPOOL.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGJOINPOOL.fields_by_name['pool_id']._options = None
  _MSGJOINPOOL.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _MSGJOINPOOL.fields_by_name['share_out_amount']._options = None
  _MSGJOINPOOL.fields_by_name['share_out_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"pool_amount_out\"\310\336\037\000'
  _MSGJOINPOOL.fields_by_name['token_in_maxs']._options = None
  _MSGJOINPOOL.fields_by_name['token_in_maxs']._serialized_options = b'\362\336\037\033yaml:\"token_in_max_amounts\"\310\336\037\000'
  _MSGJOINPOOLRESPONSE.fields_by_name['share_out_amount']._options = None
  _MSGJOINPOOLRESPONSE.fields_by_name['share_out_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\027yaml:\"share_out_amount\"\310\336\037\000'
  _MSGJOINPOOLRESPONSE.fields_by_name['token_in']._options = None
  _MSGJOINPOOLRESPONSE.fields_by_name['token_in']._serialized_options = b'\362\336\037\017yaml:\"token_in\"\310\336\037\000'
  _MSGEXITPOOL.fields_by_name['sender']._options = None
  _MSGEXITPOOL.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGEXITPOOL.fields_by_name['pool_id']._options = None
  _MSGEXITPOOL.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _MSGEXITPOOL.fields_by_name['share_in_amount']._options = None
  _MSGEXITPOOL.fields_by_name['share_in_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"share_in_amount\"\310\336\037\000'
  _MSGEXITPOOL.fields_by_name['token_out_mins']._options = None
  _MSGEXITPOOL.fields_by_name['token_out_mins']._serialized_options = b'\362\336\037\034yaml:\"token_out_min_amounts\"\310\336\037\000'
  _MSGEXITPOOLRESPONSE.fields_by_name['token_out']._options = None
  _MSGEXITPOOLRESPONSE.fields_by_name['token_out']._serialized_options = b'\362\336\037\020yaml:\"token_out\"\310\336\037\000'
  _SWAPAMOUNTINROUTE.fields_by_name['pool_id']._options = None
  _SWAPAMOUNTINROUTE.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _SWAPAMOUNTINROUTE.fields_by_name['token_out_denom']._options = None
  _SWAPAMOUNTINROUTE.fields_by_name['token_out_denom']._serialized_options = b'\362\336\037\026yaml:\"token_out_denom\"'
  _MSGSWAPEXACTAMOUNTIN.fields_by_name['sender']._options = None
  _MSGSWAPEXACTAMOUNTIN.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGSWAPEXACTAMOUNTIN.fields_by_name['routes']._options = None
  _MSGSWAPEXACTAMOUNTIN.fields_by_name['routes']._serialized_options = b'\310\336\037\000'
  _MSGSWAPEXACTAMOUNTIN.fields_by_name['token_in']._options = None
  _MSGSWAPEXACTAMOUNTIN.fields_by_name['token_in']._serialized_options = b'\362\336\037\017yaml:\"token_in\"\310\336\037\000'
  _MSGSWAPEXACTAMOUNTIN.fields_by_name['token_out_min_amount']._options = None
  _MSGSWAPEXACTAMOUNTIN.fields_by_name['token_out_min_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\033yaml:\"token_out_min_amount\"\310\336\037\000'
  _MSGSWAPEXACTAMOUNTINRESPONSE.fields_by_name['token_out_amount']._options = None
  _MSGSWAPEXACTAMOUNTINRESPONSE.fields_by_name['token_out_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\027yaml:\"token_out_amount\"\310\336\037\000'
  _SWAPAMOUNTOUTROUTE.fields_by_name['pool_id']._options = None
  _SWAPAMOUNTOUTROUTE.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _SWAPAMOUNTOUTROUTE.fields_by_name['token_in_denom']._options = None
  _SWAPAMOUNTOUTROUTE.fields_by_name['token_in_denom']._serialized_options = b'\362\336\037\026yaml:\"token_out_denom\"'
  _MSGSWAPEXACTAMOUNTOUT.fields_by_name['sender']._options = None
  _MSGSWAPEXACTAMOUNTOUT.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGSWAPEXACTAMOUNTOUT.fields_by_name['routes']._options = None
  _MSGSWAPEXACTAMOUNTOUT.fields_by_name['routes']._serialized_options = b'\310\336\037\000'
  _MSGSWAPEXACTAMOUNTOUT.fields_by_name['token_in_max_amount']._options = None
  _MSGSWAPEXACTAMOUNTOUT.fields_by_name['token_in_max_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\032yaml:\"token_in_max_amount\"\310\336\037\000'
  _MSGSWAPEXACTAMOUNTOUT.fields_by_name['token_out']._options = None
  _MSGSWAPEXACTAMOUNTOUT.fields_by_name['token_out']._serialized_options = b'\362\336\037\020yaml:\"token_out\"\310\336\037\000'
  _MSGSWAPEXACTAMOUNTOUTRESPONSE.fields_by_name['token_in_amount']._options = None
  _MSGSWAPEXACTAMOUNTOUTRESPONSE.fields_by_name['token_in_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"token_in_amount\"\310\336\037\000'
  _MSGJOINSWAPEXTERNAMOUNTIN.fields_by_name['sender']._options = None
  _MSGJOINSWAPEXTERNAMOUNTIN.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGJOINSWAPEXTERNAMOUNTIN.fields_by_name['pool_id']._options = None
  _MSGJOINSWAPEXTERNAMOUNTIN.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _MSGJOINSWAPEXTERNAMOUNTIN.fields_by_name['token_in']._options = None
  _MSGJOINSWAPEXTERNAMOUNTIN.fields_by_name['token_in']._serialized_options = b'\362\336\037\017yaml:\"token_in\"\310\336\037\000'
  _MSGJOINSWAPEXTERNAMOUNTIN.fields_by_name['share_out_min_amount']._options = None
  _MSGJOINSWAPEXTERNAMOUNTIN.fields_by_name['share_out_min_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\033yaml:\"share_out_min_amount\"\310\336\037\000'
  _MSGJOINSWAPEXTERNAMOUNTINRESPONSE.fields_by_name['share_out_amount']._options = None
  _MSGJOINSWAPEXTERNAMOUNTINRESPONSE.fields_by_name['share_out_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\027yaml:\"share_out_amount\"\310\336\037\000'
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['sender']._options = None
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['pool_id']._options = None
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['token_in_denom']._options = None
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['token_in_denom']._serialized_options = b'\362\336\037\025yaml:\"token_in_denom\"'
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['share_out_amount']._options = None
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['share_out_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\027yaml:\"share_out_amount\"\310\336\037\000'
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['token_in_max_amount']._options = None
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['token_in_max_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\032yaml:\"token_in_max_amount\"\310\336\037\000'
  _MSGJOINSWAPSHAREAMOUNTOUTRESPONSE.fields_by_name['token_in_amount']._options = None
  _MSGJOINSWAPSHAREAMOUNTOUTRESPONSE.fields_by_name['token_in_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"token_in_amount\"\310\336\037\000'
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['sender']._options = None
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['pool_id']._options = None
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['token_out_denom']._options = None
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['token_out_denom']._serialized_options = b'\362\336\037\026yaml:\"token_out_denom\"'
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['share_in_amount']._options = None
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['share_in_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"share_in_amount\"\310\336\037\000'
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['token_out_min_amount']._options = None
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['token_out_min_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\033yaml:\"token_out_min_amount\"\310\336\037\000'
  _MSGEXITSWAPSHAREAMOUNTINRESPONSE.fields_by_name['token_out_amount']._options = None
  _MSGEXITSWAPSHAREAMOUNTINRESPONSE.fields_by_name['token_out_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\027yaml:\"token_out_amount\"\310\336\037\000'
  _MSGEXITSWAPEXTERNAMOUNTOUT.fields_by_name['sender']._options = None
  _MSGEXITSWAPEXTERNAMOUNTOUT.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGEXITSWAPEXTERNAMOUNTOUT.fields_by_name['pool_id']._options = None
  _MSGEXITSWAPEXTERNAMOUNTOUT.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _MSGEXITSWAPEXTERNAMOUNTOUT.fields_by_name['token_out']._options = None
  _MSGEXITSWAPEXTERNAMOUNTOUT.fields_by_name['token_out']._serialized_options = b'\362\336\037\020yaml:\"token_out\"\310\336\037\000'
  _MSGEXITSWAPEXTERNAMOUNTOUT.fields_by_name['share_in_max_amount']._options = None
  _MSGEXITSWAPEXTERNAMOUNTOUT.fields_by_name['share_in_max_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\032yaml:\"share_in_max_amount\"\310\336\037\000'
  _MSGEXITSWAPEXTERNAMOUNTOUTRESPONSE.fields_by_name['share_in_amount']._options = None
  _MSGEXITSWAPEXTERNAMOUNTOUTRESPONSE.fields_by_name['share_in_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"share_in_amount\"\310\336\037\000'
  _MSGJOINPOOL._serialized_start=110
  _MSGJOINPOOL._serialized_end=382
  _MSGJOINPOOLRESPONSE._serialized_start=385
  _MSGJOINPOOLRESPONSE._serialized_end=577
  _MSGEXITPOOL._serialized_start=580
  _MSGEXITPOOL._serialized_end=853
  _MSGEXITPOOLRESPONSE._serialized_start=855
  _MSGEXITPOOLRESPONSE._serialized_end=948
  _SWAPAMOUNTINROUTE._serialized_start=950
  _SWAPAMOUNTINROUTE._serialized_end=1059
  _MSGSWAPEXACTAMOUNTIN._serialized_start=1062
  _MSGSWAPEXACTAMOUNTIN._serialized_end=1361
  _MSGSWAPEXACTAMOUNTINRESPONSE._serialized_start=1364
  _MSGSWAPEXACTAMOUNTINRESPONSE._serialized_end=1495
  _SWAPAMOUNTOUTROUTE._serialized_start=1497
  _SWAPAMOUNTOUTROUTE._serialized_end=1606
  _MSGSWAPEXACTAMOUNTOUT._serialized_start=1609
  _MSGSWAPEXACTAMOUNTOUT._serialized_end=1910
  _MSGSWAPEXACTAMOUNTOUTRESPONSE._serialized_start=1913
  _MSGSWAPEXACTAMOUNTOUTRESPONSE._serialized_end=2043
  _MSGJOINSWAPEXTERNAMOUNTIN._serialized_start=2046
  _MSGJOINSWAPEXTERNAMOUNTIN._serialized_end=2324
  _MSGJOINSWAPEXTERNAMOUNTINRESPONSE._serialized_start=2327
  _MSGJOINSWAPEXTERNAMOUNTINRESPONSE._serialized_end=2463
  _MSGJOINSWAPSHAREAMOUNTOUT._serialized_start=2466
  _MSGJOINSWAPSHAREAMOUNTOUT._serialized_end=2824
  _MSGJOINSWAPSHAREAMOUNTOUTRESPONSE._serialized_start=2827
  _MSGJOINSWAPSHAREAMOUNTOUTRESPONSE._serialized_end=2961
  _MSGEXITSWAPSHAREAMOUNTIN._serialized_start=2964
  _MSGEXITSWAPSHAREAMOUNTIN._serialized_end=3323
  _MSGEXITSWAPSHAREAMOUNTINRESPONSE._serialized_start=3326
  _MSGEXITSWAPSHAREAMOUNTINRESPONSE._serialized_end=3461
  _MSGEXITSWAPEXTERNAMOUNTOUT._serialized_start=3464
  _MSGEXITSWAPEXTERNAMOUNTOUT._serialized_end=3743
  _MSGEXITSWAPEXTERNAMOUNTOUTRESPONSE._serialized_start=3746
  _MSGEXITSWAPEXTERNAMOUNTOUTRESPONSE._serialized_end=3881
  _MSG._serialized_start=3884
  _MSG._serialized_end=4837
# @@protoc_insertion_point(module_scope)
