"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Since: cosmos-sdk 0.43"""
import builtins
import collections.abc
import cosmos.feegrant.v1beta1.feegrant_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState contains a set of fee allowances, persisted from the store"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWANCES_FIELD_NUMBER: builtins.int
    @property
    def allowances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.feegrant.v1beta1.feegrant_pb2.Grant]: ...
    def __init__(
        self,
        *,
        allowances: collections.abc.Iterable[cosmos.feegrant.v1beta1.feegrant_pb2.Grant] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowances", b"allowances"]) -> None: ...

global___GenesisState = GenesisState
