"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import osmosis.twap.v1beta1.genesis_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ArithmeticTwapRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    BASE_ASSET_FIELD_NUMBER: builtins.int
    QUOTE_ASSET_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    base_asset: builtins.str
    quote_asset: builtins.str
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        base_asset: builtins.str = ...,
        quote_asset: builtins.str = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_asset", b"base_asset", "end_time", b"end_time", "pool_id", b"pool_id", "quote_asset", b"quote_asset", "start_time", b"start_time"]) -> None: ...

global___ArithmeticTwapRequest = ArithmeticTwapRequest

@typing_extensions.final
class ArithmeticTwapResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARITHMETIC_TWAP_FIELD_NUMBER: builtins.int
    arithmetic_twap: builtins.str
    def __init__(
        self,
        *,
        arithmetic_twap: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arithmetic_twap", b"arithmetic_twap"]) -> None: ...

global___ArithmeticTwapResponse = ArithmeticTwapResponse

@typing_extensions.final
class ArithmeticTwapToNowRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    BASE_ASSET_FIELD_NUMBER: builtins.int
    QUOTE_ASSET_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    base_asset: builtins.str
    quote_asset: builtins.str
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        base_asset: builtins.str = ...,
        quote_asset: builtins.str = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_asset", b"base_asset", "pool_id", b"pool_id", "quote_asset", b"quote_asset", "start_time", b"start_time"]) -> None: ...

global___ArithmeticTwapToNowRequest = ArithmeticTwapToNowRequest

@typing_extensions.final
class ArithmeticTwapToNowResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARITHMETIC_TWAP_FIELD_NUMBER: builtins.int
    arithmetic_twap: builtins.str
    def __init__(
        self,
        *,
        arithmetic_twap: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arithmetic_twap", b"arithmetic_twap"]) -> None: ...

global___ArithmeticTwapToNowResponse = ArithmeticTwapToNowResponse

@typing_extensions.final
class GeometricTwapRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    BASE_ASSET_FIELD_NUMBER: builtins.int
    QUOTE_ASSET_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    base_asset: builtins.str
    quote_asset: builtins.str
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        base_asset: builtins.str = ...,
        quote_asset: builtins.str = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_asset", b"base_asset", "end_time", b"end_time", "pool_id", b"pool_id", "quote_asset", b"quote_asset", "start_time", b"start_time"]) -> None: ...

global___GeometricTwapRequest = GeometricTwapRequest

@typing_extensions.final
class GeometricTwapResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GEOMETRIC_TWAP_FIELD_NUMBER: builtins.int
    geometric_twap: builtins.str
    def __init__(
        self,
        *,
        geometric_twap: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["geometric_twap", b"geometric_twap"]) -> None: ...

global___GeometricTwapResponse = GeometricTwapResponse

@typing_extensions.final
class GeometricTwapToNowRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    BASE_ASSET_FIELD_NUMBER: builtins.int
    QUOTE_ASSET_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    base_asset: builtins.str
    quote_asset: builtins.str
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        base_asset: builtins.str = ...,
        quote_asset: builtins.str = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_asset", b"base_asset", "pool_id", b"pool_id", "quote_asset", b"quote_asset", "start_time", b"start_time"]) -> None: ...

global___GeometricTwapToNowRequest = GeometricTwapToNowRequest

@typing_extensions.final
class GeometricTwapToNowResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GEOMETRIC_TWAP_FIELD_NUMBER: builtins.int
    geometric_twap: builtins.str
    def __init__(
        self,
        *,
        geometric_twap: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["geometric_twap", b"geometric_twap"]) -> None: ...

global___GeometricTwapToNowResponse = GeometricTwapToNowResponse

@typing_extensions.final
class ParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ParamsRequest = ParamsRequest

@typing_extensions.final
class ParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> osmosis.twap.v1beta1.genesis_pb2.Params: ...
    def __init__(
        self,
        *,
        params: osmosis.twap.v1beta1.genesis_pb2.Params | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___ParamsResponse = ParamsResponse
