"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.evidence.v1beta1.tx_pb2
import grpc

class MsgStub:
    """Msg defines the evidence Msg service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    SubmitEvidence: grpc.UnaryUnaryMultiCallable[
        cosmos.evidence.v1beta1.tx_pb2.MsgSubmitEvidence,
        cosmos.evidence.v1beta1.tx_pb2.MsgSubmitEvidenceResponse,
    ]
    """SubmitEvidence submits an arbitrary Evidence of misbehavior such as equivocation or
    counterfactual signing.
    """

class MsgServicer(metaclass=abc.ABCMeta):
    """Msg defines the evidence Msg service."""

    @abc.abstractmethod
    def SubmitEvidence(
        self,
        request: cosmos.evidence.v1beta1.tx_pb2.MsgSubmitEvidence,
        context: grpc.ServicerContext,
    ) -> cosmos.evidence.v1beta1.tx_pb2.MsgSubmitEvidenceResponse:
        """SubmitEvidence submits an arbitrary Evidence of misbehavior such as equivocation or
        counterfactual signing.
        """

def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...
