"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MsgSuperfluidDelegate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    LOCK_ID_FIELD_NUMBER: builtins.int
    VAL_ADDR_FIELD_NUMBER: builtins.int
    sender: builtins.str
    lock_id: builtins.int
    val_addr: builtins.str
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        lock_id: builtins.int = ...,
        val_addr: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lock_id", b"lock_id", "sender", b"sender", "val_addr", b"val_addr"]) -> None: ...

global___MsgSuperfluidDelegate = MsgSuperfluidDelegate

@typing_extensions.final
class MsgSuperfluidDelegateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgSuperfluidDelegateResponse = MsgSuperfluidDelegateResponse

@typing_extensions.final
class MsgSuperfluidUndelegate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    LOCK_ID_FIELD_NUMBER: builtins.int
    sender: builtins.str
    lock_id: builtins.int
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        lock_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lock_id", b"lock_id", "sender", b"sender"]) -> None: ...

global___MsgSuperfluidUndelegate = MsgSuperfluidUndelegate

@typing_extensions.final
class MsgSuperfluidUndelegateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgSuperfluidUndelegateResponse = MsgSuperfluidUndelegateResponse

@typing_extensions.final
class MsgSuperfluidUnbondLock(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    LOCK_ID_FIELD_NUMBER: builtins.int
    sender: builtins.str
    lock_id: builtins.int
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        lock_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lock_id", b"lock_id", "sender", b"sender"]) -> None: ...

global___MsgSuperfluidUnbondLock = MsgSuperfluidUnbondLock

@typing_extensions.final
class MsgSuperfluidUnbondLockResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgSuperfluidUnbondLockResponse = MsgSuperfluidUnbondLockResponse

@typing_extensions.final
class MsgLockAndSuperfluidDelegate(google.protobuf.message.Message):
    """message MsgSuperfluidRedelegate {
      string sender = 1 [ (gogoproto.moretags) = "yaml:\\"sender\\"" ];
      uint64 lock_id = 2;
      string new_val_addr = 3;
    }
    message MsgSuperfluidRedelegateResponse {}

    MsgLockAndSuperfluidDelegate locks coins with the unbonding period duration,
    and then does a superfluid lock from the newly created lockup, to the
    specified validator addr.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    COINS_FIELD_NUMBER: builtins.int
    VAL_ADDR_FIELD_NUMBER: builtins.int
    sender: builtins.str
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    val_addr: builtins.str
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        val_addr: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["coins", b"coins", "sender", b"sender", "val_addr", b"val_addr"]) -> None: ...

global___MsgLockAndSuperfluidDelegate = MsgLockAndSuperfluidDelegate

@typing_extensions.final
class MsgLockAndSuperfluidDelegateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ID: builtins.int
    def __init__(
        self,
        *,
        ID: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ID", b"ID"]) -> None: ...

global___MsgLockAndSuperfluidDelegateResponse = MsgLockAndSuperfluidDelegateResponse

@typing_extensions.final
class MsgUnPoolWhitelistedPool(google.protobuf.message.Message):
    """MsgUnPoolWhitelistedPool Unpools every lock the sender has, that is
    associated with pool pool_id. If pool_id is not approved for unpooling by
    governance, this is a no-op. Unpooling takes the locked gamm shares, and runs
    "ExitPool" on it, to get the constituent tokens. e.g. z gamm/pool/1 tokens
    ExitPools into constituent tokens x uatom, y uosmo. Then it creates a new
    lock for every constituent token, with the duration associated with the lock.
    If the lock was unbonding, the new lockup durations should be the time left
    until unbond completion.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    sender: builtins.str
    pool_id: builtins.int
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        pool_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id", "sender", b"sender"]) -> None: ...

global___MsgUnPoolWhitelistedPool = MsgUnPoolWhitelistedPool

@typing_extensions.final
class MsgUnPoolWhitelistedPoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXITED_LOCK_IDS_FIELD_NUMBER: builtins.int
    @property
    def exited_lock_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        exited_lock_ids: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exited_lock_ids", b"exited_lock_ids"]) -> None: ...

global___MsgUnPoolWhitelistedPoolResponse = MsgUnPoolWhitelistedPoolResponse
