"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Coin(google.protobuf.message.Message):
    """Coin defines a token with a denomination and an amount.

    NOTE: The amount field is an Int which implements the custom method
    signatures required by gogoproto.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    denom: builtins.str
    amount: builtins.str
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
        amount: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "denom", b"denom"]) -> None: ...

global___Coin = Coin

@typing_extensions.final
class DecCoin(google.protobuf.message.Message):
    """DecCoin defines a token with a denomination and a decimal amount.

    NOTE: The amount field is an Dec which implements the custom method
    signatures required by gogoproto.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    denom: builtins.str
    amount: builtins.str
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
        amount: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "denom", b"denom"]) -> None: ...

global___DecCoin = DecCoin

@typing_extensions.final
class IntProto(google.protobuf.message.Message):
    """IntProto defines a Protobuf wrapper around an Int object."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INT_FIELD_NUMBER: builtins.int
    int: builtins.str
    def __init__(
        self,
        *,
        int: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["int", b"int"]) -> None: ...

global___IntProto = IntProto

@typing_extensions.final
class DecProto(google.protobuf.message.Message):
    """DecProto defines a Protobuf wrapper around a Dec object."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEC_FIELD_NUMBER: builtins.int
    dec: builtins.str
    def __init__(
        self,
        *,
        dec: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dec", b"dec"]) -> None: ...

global___DecProto = DecProto
