"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.mint.v1beta1.query_pb2

class QueryStub:
    """Query provides defines the gRPC querier service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    Params: grpc.UnaryUnaryMultiCallable[
        osmosis.mint.v1beta1.query_pb2.QueryParamsRequest,
        osmosis.mint.v1beta1.query_pb2.QueryParamsResponse,
    ]
    """Params returns the total set of minting parameters."""
    EpochProvisions: grpc.UnaryUnaryMultiCallable[
        osmosis.mint.v1beta1.query_pb2.QueryEpochProvisionsRequest,
        osmosis.mint.v1beta1.query_pb2.QueryEpochProvisionsResponse,
    ]
    """EpochProvisions returns the current minting epoch provisions value."""

class QueryServicer(metaclass=abc.ABCMeta):
    """Query provides defines the gRPC querier service."""

    @abc.abstractmethod
    def Params(
        self,
        request: osmosis.mint.v1beta1.query_pb2.QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.mint.v1beta1.query_pb2.QueryParamsResponse:
        """Params returns the total set of minting parameters."""
    @abc.abstractmethod
    def EpochProvisions(
        self,
        request: osmosis.mint.v1beta1.query_pb2.QueryEpochProvisionsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.mint.v1beta1.query_pb2.QueryEpochProvisionsResponse:
        """EpochProvisions returns the current minting epoch provisions value."""

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...
