"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class PubKey(google.protobuf.message.Message):
    """PubKey is an ed25519 public key for handling Tendermint keys in SDK.
    It's needed for Any serialization and SDK compatibility.
    It must not be used in a non Tendermint key context because it doesn't implement
    ADR-28. Nevertheless, you will like to use ed25519 in app user level
    then you must create a new proto message and follow ADR-28 for Address construction.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    key: builtins.bytes
    def __init__(
        self,
        *,
        key: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key"]) -> None: ...

global___PubKey = PubKey

@typing_extensions.final
class PrivKey(google.protobuf.message.Message):
    """Deprecated: PrivKey defines a ed25519 private key.
    NOTE: ed25519 keys must not be used in SDK apps except in a tendermint validator context.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    key: builtins.bytes
    def __init__(
        self,
        *,
        key: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key"]) -> None: ...

global___PrivKey = PrivKey
