"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Since: cosmos-sdk 0.43"""
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the authz module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHORIZATION_FIELD_NUMBER: builtins.int
    @property
    def authorization(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GrantAuthorization]: ...
    def __init__(
        self,
        *,
        authorization: collections.abc.Iterable[global___GrantAuthorization] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorization", b"authorization"]) -> None: ...

global___GenesisState = GenesisState

@typing_extensions.final
class GrantAuthorization(google.protobuf.message.Message):
    """GrantAuthorization defines the GenesisState/GrantAuthorization type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    AUTHORIZATION_FIELD_NUMBER: builtins.int
    EXPIRATION_FIELD_NUMBER: builtins.int
    granter: builtins.str
    grantee: builtins.str
    @property
    def authorization(self) -> google.protobuf.any_pb2.Any: ...
    @property
    def expiration(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        granter: builtins.str = ...,
        grantee: builtins.str = ...,
        authorization: google.protobuf.any_pb2.Any | None = ...,
        expiration: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authorization", b"authorization", "expiration", b"expiration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorization", b"authorization", "expiration", b"expiration", "grantee", b"grantee", "granter", b"granter"]) -> None: ...

global___GrantAuthorization = GrantAuthorization
