"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.pool_incentives.v1beta1.incentives_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the pool incentives module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    LOCKABLE_DURATIONS_FIELD_NUMBER: builtins.int
    DISTR_INFO_FIELD_NUMBER: builtins.int
    POOL_TO_GAUGES_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> osmosis.pool_incentives.v1beta1.incentives_pb2.Params:
        """params defines all the paramaters of the module."""
    @property
    def lockable_durations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.duration_pb2.Duration]: ...
    @property
    def distr_info(self) -> osmosis.pool_incentives.v1beta1.incentives_pb2.DistrInfo: ...
    @property
    def pool_to_gauges(self) -> osmosis.pool_incentives.v1beta1.incentives_pb2.PoolToGauges: ...
    def __init__(
        self,
        *,
        params: osmosis.pool_incentives.v1beta1.incentives_pb2.Params | None = ...,
        lockable_durations: collections.abc.Iterable[google.protobuf.duration_pb2.Duration] | None = ...,
        distr_info: osmosis.pool_incentives.v1beta1.incentives_pb2.DistrInfo | None = ...,
        pool_to_gauges: osmosis.pool_incentives.v1beta1.incentives_pb2.PoolToGauges | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["distr_info", b"distr_info", "params", b"params", "pool_to_gauges", b"pool_to_gauges"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["distr_info", b"distr_info", "lockable_durations", b"lockable_durations", "params", b"params", "pool_to_gauges", b"pool_to_gauges"]) -> None: ...

global___GenesisState = GenesisState
