"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MsgSetWithdrawAddress(google.protobuf.message.Message):
    """MsgSetWithdrawAddress sets the withdraw address for
    a delegator (or validator self-delegation).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    WITHDRAW_ADDRESS_FIELD_NUMBER: builtins.int
    delegator_address: builtins.str
    withdraw_address: builtins.str
    def __init__(
        self,
        *,
        delegator_address: builtins.str = ...,
        withdraw_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_address", b"delegator_address", "withdraw_address", b"withdraw_address"]) -> None: ...

global___MsgSetWithdrawAddress = MsgSetWithdrawAddress

@typing_extensions.final
class MsgSetWithdrawAddressResponse(google.protobuf.message.Message):
    """MsgSetWithdrawAddressResponse defines the Msg/SetWithdrawAddress response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgSetWithdrawAddressResponse = MsgSetWithdrawAddressResponse

@typing_extensions.final
class MsgWithdrawDelegatorReward(google.protobuf.message.Message):
    """MsgWithdrawDelegatorReward represents delegation withdrawal to a delegator
    from a single validator.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    delegator_address: builtins.str
    validator_address: builtins.str
    def __init__(
        self,
        *,
        delegator_address: builtins.str = ...,
        validator_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_address", b"delegator_address", "validator_address", b"validator_address"]) -> None: ...

global___MsgWithdrawDelegatorReward = MsgWithdrawDelegatorReward

@typing_extensions.final
class MsgWithdrawDelegatorRewardResponse(google.protobuf.message.Message):
    """MsgWithdrawDelegatorRewardResponse defines the Msg/WithdrawDelegatorReward response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgWithdrawDelegatorRewardResponse = MsgWithdrawDelegatorRewardResponse

@typing_extensions.final
class MsgWithdrawValidatorCommission(google.protobuf.message.Message):
    """MsgWithdrawValidatorCommission withdraws the full commission to the validator
    address.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    validator_address: builtins.str
    def __init__(
        self,
        *,
        validator_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["validator_address", b"validator_address"]) -> None: ...

global___MsgWithdrawValidatorCommission = MsgWithdrawValidatorCommission

@typing_extensions.final
class MsgWithdrawValidatorCommissionResponse(google.protobuf.message.Message):
    """MsgWithdrawValidatorCommissionResponse defines the Msg/WithdrawValidatorCommission response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgWithdrawValidatorCommissionResponse = MsgWithdrawValidatorCommissionResponse

@typing_extensions.final
class MsgFundCommunityPool(google.protobuf.message.Message):
    """MsgFundCommunityPool allows an account to directly
    fund the community pool.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AMOUNT_FIELD_NUMBER: builtins.int
    DEPOSITOR_FIELD_NUMBER: builtins.int
    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    depositor: builtins.str
    def __init__(
        self,
        *,
        amount: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        depositor: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "depositor", b"depositor"]) -> None: ...

global___MsgFundCommunityPool = MsgFundCommunityPool

@typing_extensions.final
class MsgFundCommunityPoolResponse(google.protobuf.message.Message):
    """MsgFundCommunityPoolResponse defines the Msg/FundCommunityPool response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgFundCommunityPoolResponse = MsgFundCommunityPoolResponse
