# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from cosmos.vesting.v1beta1 import tx_pb2 as cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the bank Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateVestingAccount = channel.unary_unary(
                '/cosmos.vesting.v1beta1.Msg/CreateVestingAccount',
                request_serializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateVestingAccount.SerializeToString,
                response_deserializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateVestingAccountResponse.FromString,
                )
        self.CreateClawbackVestingAccount = channel.unary_unary(
                '/cosmos.vesting.v1beta1.Msg/CreateClawbackVestingAccount',
                request_serializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateClawbackVestingAccount.SerializeToString,
                response_deserializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateClawbackVestingAccountResponse.FromString,
                )
        self.Clawback = channel.unary_unary(
                '/cosmos.vesting.v1beta1.Msg/Clawback',
                request_serializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgClawback.SerializeToString,
                response_deserializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgClawbackResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the bank Msg service.
    """

    def CreateVestingAccount(self, request, context):
        """CreateVestingAccount defines a method that enables creating a vesting
        account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateClawbackVestingAccount(self, request, context):
        """CreateClawbackVestingAccount creats a vesting account that is subject to
        clawback and the configuration of vesting and lockup schedules.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Clawback(self, request, context):
        """Clawback removes the unvested tokens from a ClawbackVestingAccount.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateVestingAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateVestingAccount,
                    request_deserializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateVestingAccount.FromString,
                    response_serializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateVestingAccountResponse.SerializeToString,
            ),
            'CreateClawbackVestingAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateClawbackVestingAccount,
                    request_deserializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateClawbackVestingAccount.FromString,
                    response_serializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateClawbackVestingAccountResponse.SerializeToString,
            ),
            'Clawback': grpc.unary_unary_rpc_method_handler(
                    servicer.Clawback,
                    request_deserializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgClawback.FromString,
                    response_serializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgClawbackResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.vesting.v1beta1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the bank Msg service.
    """

    @staticmethod
    def CreateVestingAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.vesting.v1beta1.Msg/CreateVestingAccount',
            cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateVestingAccount.SerializeToString,
            cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateVestingAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateClawbackVestingAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.vesting.v1beta1.Msg/CreateClawbackVestingAccount',
            cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateClawbackVestingAccount.SerializeToString,
            cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateClawbackVestingAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Clawback(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.vesting.v1beta1.Msg/Clawback',
            cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgClawback.SerializeToString,
            cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgClawbackResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
