"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Since: cosmos-sdk 0.43"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class EventGrant(google.protobuf.message.Message):
    """EventGrant is emitted on Msg/Grant"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_TYPE_URL_FIELD_NUMBER: builtins.int
    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    msg_type_url: builtins.str
    """Msg type URL for which an autorization is granted"""
    granter: builtins.str
    """Granter account address"""
    grantee: builtins.str
    """Grantee account address"""
    def __init__(
        self,
        *,
        msg_type_url: builtins.str = ...,
        granter: builtins.str = ...,
        grantee: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["grantee", b"grantee", "granter", b"granter", "msg_type_url", b"msg_type_url"]) -> None: ...

global___EventGrant = EventGrant

@typing_extensions.final
class EventRevoke(google.protobuf.message.Message):
    """EventRevoke is emitted on Msg/Revoke"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_TYPE_URL_FIELD_NUMBER: builtins.int
    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    msg_type_url: builtins.str
    """Msg type URL for which an autorization is revoked"""
    granter: builtins.str
    """Granter account address"""
    grantee: builtins.str
    """Grantee account address"""
    def __init__(
        self,
        *,
        msg_type_url: builtins.str = ...,
        granter: builtins.str = ...,
        grantee: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["grantee", b"grantee", "granter", b"granter", "msg_type_url", b"msg_type_url"]) -> None: ...

global___EventRevoke = EventRevoke
