"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
this is a legacy package that requires additional migration logic
in order to use the correct packge. Decision made to use legacy package path
until clear steps for migration logic and the unknowns for state breaking are
investigated for changing proto package.
"""
