"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class App(google.protobuf.message.Message):
    """App includes the protocol and software version for the application.
    This information is included in ResponseInfo. The App.Protocol can be
    updated in ResponseEndBlock.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTOCOL_FIELD_NUMBER: builtins.int
    SOFTWARE_FIELD_NUMBER: builtins.int
    protocol: builtins.int
    software: builtins.str
    def __init__(
        self,
        *,
        protocol: builtins.int = ...,
        software: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["protocol", b"protocol", "software", b"software"]) -> None: ...

global___App = App

@typing_extensions.final
class Consensus(google.protobuf.message.Message):
    """Consensus captures the consensus rules for processing a block in the blockchain,
    including all blockchain data structures and the rules of the application's
    state transition machine.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOCK_FIELD_NUMBER: builtins.int
    APP_FIELD_NUMBER: builtins.int
    block: builtins.int
    app: builtins.int
    def __init__(
        self,
        *,
        block: builtins.int = ...,
        app: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app", b"app", "block", b"block"]) -> None: ...

global___Consensus = Consensus
