"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.gamm.pool_models.stableswap.stableswap_pool_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MsgCreateStableswapPool(google.protobuf.message.Message):
    """===================== MsgCreatePool"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    POOL_PARAMS_FIELD_NUMBER: builtins.int
    INITIAL_POOL_LIQUIDITY_FIELD_NUMBER: builtins.int
    SCALING_FACTORS_FIELD_NUMBER: builtins.int
    FUTURE_POOL_GOVERNOR_FIELD_NUMBER: builtins.int
    SCALING_FACTOR_CONTROLLER_FIELD_NUMBER: builtins.int
    sender: builtins.str
    @property
    def pool_params(self) -> osmosis.gamm.pool_models.stableswap.stableswap_pool_pb2.PoolParams: ...
    @property
    def initial_pool_liquidity(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    @property
    def scaling_factors(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    future_pool_governor: builtins.str
    scaling_factor_controller: builtins.str
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        pool_params: osmosis.gamm.pool_models.stableswap.stableswap_pool_pb2.PoolParams | None = ...,
        initial_pool_liquidity: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        scaling_factors: collections.abc.Iterable[builtins.int] | None = ...,
        future_pool_governor: builtins.str = ...,
        scaling_factor_controller: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pool_params", b"pool_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["future_pool_governor", b"future_pool_governor", "initial_pool_liquidity", b"initial_pool_liquidity", "pool_params", b"pool_params", "scaling_factor_controller", b"scaling_factor_controller", "scaling_factors", b"scaling_factors", "sender", b"sender"]) -> None: ...

global___MsgCreateStableswapPool = MsgCreateStableswapPool

@typing_extensions.final
class MsgCreateStableswapPoolResponse(google.protobuf.message.Message):
    """Returns a poolID with custom poolName."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id"]) -> None: ...

global___MsgCreateStableswapPoolResponse = MsgCreateStableswapPoolResponse

@typing_extensions.final
class MsgStableSwapAdjustScalingFactors(google.protobuf.message.Message):
    """Sender must be the pool's scaling_factor_governor in order for the tx to
    succeed. Adjusts stableswap scaling factors.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    SCALING_FACTORS_FIELD_NUMBER: builtins.int
    sender: builtins.str
    pool_id: builtins.int
    @property
    def scaling_factors(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        pool_id: builtins.int = ...,
        scaling_factors: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id", "scaling_factors", b"scaling_factors", "sender", b"sender"]) -> None: ...

global___MsgStableSwapAdjustScalingFactors = MsgStableSwapAdjustScalingFactors

@typing_extensions.final
class MsgStableSwapAdjustScalingFactorsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgStableSwapAdjustScalingFactorsResponse = MsgStableSwapAdjustScalingFactorsResponse
