# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/lockup/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from google_apis.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from osmosis.lockup import lock_pb2 as osmosis_dot_lockup_dot_lock__pb2
from osmosis.lockup import params_pb2 as osmosis_dot_lockup_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aosmosis/lockup/query.proto\x12\x0eosmosis.lockup\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x19osmosis/lockup/lock.proto\x1a\x1bosmosis/lockup/params.proto\"\x16\n\x14ModuleBalanceRequest\"s\n\x15ModuleBalanceResponse\x12Z\n\x05\x63oins\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\x1b\n\x19ModuleLockedAmountRequest\"x\n\x1aModuleLockedAmountResponse\x12Z\n\x05\x63oins\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"@\n\x1d\x41\x63\x63ountUnlockableCoinsRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\"|\n\x1e\x41\x63\x63ountUnlockableCoinsResponse\x12Z\n\x05\x63oins\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"?\n\x1c\x41\x63\x63ountUnlockingCoinsRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\"{\n\x1d\x41\x63\x63ountUnlockingCoinsResponse\x12Z\n\x05\x63oins\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"<\n\x19\x41\x63\x63ountLockedCoinsRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\"x\n\x1a\x41\x63\x63ountLockedCoinsResponse\x12Z\n\x05\x63oins\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\x8c\x01\n\x1c\x41\x63\x63ountLockedPastTimeRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12K\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1c\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x10yaml:\"timestamp\"\"P\n\x1d\x41\x63\x63ountLockedPastTimeResponse\x12/\n\x05locks\x18\x01 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLockB\x04\xc8\xde\x1f\x00\"\x9c\x01\n,AccountLockedPastTimeNotUnlockingOnlyRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12K\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1c\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x10yaml:\"timestamp\"\"`\n-AccountLockedPastTimeNotUnlockingOnlyResponse\x12/\n\x05locks\x18\x01 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLockB\x04\xc8\xde\x1f\x00\"\x90\x01\n AccountUnlockedBeforeTimeRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12K\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1c\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x10yaml:\"timestamp\"\"T\n!AccountUnlockedBeforeTimeResponse\x12/\n\x05locks\x18\x01 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLockB\x04\xc8\xde\x1f\x00\"\xa0\x01\n!AccountLockedPastTimeDenomRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12K\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1c\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x10yaml:\"timestamp\"\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\"U\n\"AccountLockedPastTimeDenomResponse\x12/\n\x05locks\x18\x01 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLockB\x04\xc8\xde\x1f\x00\"m\n\x12LockedDenomRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12H\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x1b\x98\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"duration\"\"f\n\x13LockedDenomResponse\x12O\n\x06\x61mount\x18\x01 \x01(\tB?\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\ryaml:\"amount\"\xc8\xde\x1f\x00\" \n\rLockedRequest\x12\x0f\n\x07lock_id\x18\x01 \x01(\x04\":\n\x0eLockedResponse\x12(\n\x04lock\x18\x01 \x01(\x0b\x32\x1a.osmosis.lockup.PeriodLock\"4\n!SyntheticLockupsByLockupIDRequest\x12\x0f\n\x07lock_id\x18\x01 \x01(\x04\"b\n\"SyntheticLockupsByLockupIDResponse\x12<\n\x0fsynthetic_locks\x18\x01 \x03(\x0b\x32\x1d.osmosis.lockup.SyntheticLockB\x04\xc8\xde\x1f\x00\"\x8f\x01\n\"AccountLockedLongerDurationRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12H\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x1b\x98\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"duration\"\"V\n#AccountLockedLongerDurationResponse\x12/\n\x05locks\x18\x01 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLockB\x04\xc8\xde\x1f\x00\"\x89\x01\n\x1c\x41\x63\x63ountLockedDurationRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12H\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x1b\x98\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"duration\"\"P\n\x1d\x41\x63\x63ountLockedDurationResponse\x12/\n\x05locks\x18\x01 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLockB\x04\xc8\xde\x1f\x00\"\x9f\x01\n2AccountLockedLongerDurationNotUnlockingOnlyRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12H\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x1b\x98\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"duration\"\"f\n3AccountLockedLongerDurationNotUnlockingOnlyResponse\x12/\n\x05locks\x18\x01 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLockB\x04\xc8\xde\x1f\x00\"\xa3\x01\n\'AccountLockedLongerDurationDenomRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12H\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x1b\x98\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"duration\"\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\"[\n(AccountLockedLongerDurationDenomResponse\x12/\n\x05locks\x18\x01 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLockB\x04\xc8\xde\x1f\x00\"\x14\n\x12QueryParamsRequest\"C\n\x13QueryParamsResponse\x12,\n\x06params\x18\x01 \x01(\x0b\x32\x16.osmosis.lockup.ParamsB\x04\xc8\xde\x1f\x00\x32\xfc\x18\n\x05Query\x12\x8c\x01\n\rModuleBalance\x12$.osmosis.lockup.ModuleBalanceRequest\x1a%.osmosis.lockup.ModuleBalanceResponse\".\x82\xd3\xe4\x93\x02(\x12&/osmosis/lockup/v1beta1/module_balance\x12\xa1\x01\n\x12ModuleLockedAmount\x12).osmosis.lockup.ModuleLockedAmountRequest\x1a*.osmosis.lockup.ModuleLockedAmountResponse\"4\x82\xd3\xe4\x93\x02.\x12,/osmosis/lockup/v1beta1/module_locked_amount\x12\xb9\x01\n\x16\x41\x63\x63ountUnlockableCoins\x12-.osmosis.lockup.AccountUnlockableCoinsRequest\x1a..osmosis.lockup.AccountUnlockableCoinsResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/osmosis/lockup/v1beta1/account_unlockable_coins/{owner}\x12\xb5\x01\n\x15\x41\x63\x63ountUnlockingCoins\x12,.osmosis.lockup.AccountUnlockingCoinsRequest\x1a-.osmosis.lockup.AccountUnlockingCoinsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/osmosis/lockup/v1beta1/account_unlocking_coins/{owner}\x12\xa9\x01\n\x12\x41\x63\x63ountLockedCoins\x12).osmosis.lockup.AccountLockedCoinsRequest\x1a*.osmosis.lockup.AccountLockedCoinsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/osmosis/lockup/v1beta1/account_locked_coins/{owner}\x12\xb5\x01\n\x15\x41\x63\x63ountLockedPastTime\x12,.osmosis.lockup.AccountLockedPastTimeRequest\x1a-.osmosis.lockup.AccountLockedPastTimeResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/osmosis/lockup/v1beta1/account_locked_pasttime/{owner}\x12\xf8\x01\n%AccountLockedPastTimeNotUnlockingOnly\x12<.osmosis.lockup.AccountLockedPastTimeNotUnlockingOnlyRequest\x1a=.osmosis.lockup.AccountLockedPastTimeNotUnlockingOnlyResponse\"R\x82\xd3\xe4\x93\x02L\x12J/osmosis/lockup/v1beta1/account_locked_pasttime_not_unlocking_only/{owner}\x12\xc6\x01\n\x19\x41\x63\x63ountUnlockedBeforeTime\x12\x30.osmosis.lockup.AccountUnlockedBeforeTimeRequest\x1a\x31.osmosis.lockup.AccountUnlockedBeforeTimeResponse\"D\x82\xd3\xe4\x93\x02>\x12</osmosis/lockup/v1beta1/account_unlocked_before_time/{owner}\x12\xca\x01\n\x1a\x41\x63\x63ountLockedPastTimeDenom\x12\x31.osmosis.lockup.AccountLockedPastTimeDenomRequest\x1a\x32.osmosis.lockup.AccountLockedPastTimeDenomResponse\"E\x82\xd3\xe4\x93\x02?\x12=/osmosis/lockup/v1beta1/account_locked_pasttime_denom/{owner}\x12\x84\x01\n\x0bLockedDenom\x12\".osmosis.lockup.LockedDenomRequest\x1a#.osmosis.lockup.LockedDenomResponse\",\x82\xd3\xe4\x93\x02&\x12$/osmosis/lockup/v1beta1/locked_denom\x12\x83\x01\n\nLockedByID\x12\x1d.osmosis.lockup.LockedRequest\x1a\x1e.osmosis.lockup.LockedResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./osmosis/lockup/v1beta1/locked_by_id/{lock_id}\x12\xcb\x01\n\x1aSyntheticLockupsByLockupID\x12\x31.osmosis.lockup.SyntheticLockupsByLockupIDRequest\x1a\x32.osmosis.lockup.SyntheticLockupsByLockupIDResponse\"F\x82\xd3\xe4\x93\x02@\x12>/osmosis/lockup/v1beta1/synthetic_lockups_by_lock_id/{lock_id}\x12\xce\x01\n\x1b\x41\x63\x63ountLockedLongerDuration\x12\x32.osmosis.lockup.AccountLockedLongerDurationRequest\x1a\x33.osmosis.lockup.AccountLockedLongerDurationResponse\"F\x82\xd3\xe4\x93\x02@\x12>/osmosis/lockup/v1beta1/account_locked_longer_duration/{owner}\x12\xb5\x01\n\x15\x41\x63\x63ountLockedDuration\x12,.osmosis.lockup.AccountLockedDurationRequest\x1a-.osmosis.lockup.AccountLockedDurationResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/osmosis/lockup/v1beta1/account_locked_duration/{owner}\x12\x91\x02\n+AccountLockedLongerDurationNotUnlockingOnly\x12\x42.osmosis.lockup.AccountLockedLongerDurationNotUnlockingOnlyRequest\x1a\x43.osmosis.lockup.AccountLockedLongerDurationNotUnlockingOnlyResponse\"Y\x82\xd3\xe4\x93\x02S\x12Q/osmosis/lockup/v1beta1/account_locked_longer_duration_not_unlocking_only/{owner}\x12\xe3\x01\n AccountLockedLongerDurationDenom\x12\x37.osmosis.lockup.AccountLockedLongerDurationDenomRequest\x1a\x38.osmosis.lockup.AccountLockedLongerDurationDenomResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/osmosis/lockup/v1beta1/account_locked_longer_duration_denom/{owner}\x12y\n\x06Params\x12\".osmosis.lockup.QueryParamsRequest\x1a#.osmosis.lockup.QueryParamsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/osmosis/lockup/v1beta1/paramsB4Z2github.com/osmosis-labs/osmosis/v14/x/lockup/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.lockup.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/osmosis-labs/osmosis/v14/x/lockup/types'
  _MODULEBALANCERESPONSE.fields_by_name['coins']._options = None
  _MODULEBALANCERESPONSE.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MODULELOCKEDAMOUNTRESPONSE.fields_by_name['coins']._options = None
  _MODULELOCKEDAMOUNTRESPONSE.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _ACCOUNTUNLOCKABLECOINSREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTUNLOCKABLECOINSREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTUNLOCKABLECOINSRESPONSE.fields_by_name['coins']._options = None
  _ACCOUNTUNLOCKABLECOINSRESPONSE.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _ACCOUNTUNLOCKINGCOINSREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTUNLOCKINGCOINSREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTUNLOCKINGCOINSRESPONSE.fields_by_name['coins']._options = None
  _ACCOUNTUNLOCKINGCOINSRESPONSE.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _ACCOUNTLOCKEDCOINSREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTLOCKEDCOINSREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTLOCKEDCOINSRESPONSE.fields_by_name['coins']._options = None
  _ACCOUNTLOCKEDCOINSRESPONSE.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _ACCOUNTLOCKEDPASTTIMEREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTLOCKEDPASTTIMEREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTLOCKEDPASTTIMEREQUEST.fields_by_name['timestamp']._options = None
  _ACCOUNTLOCKEDPASTTIMEREQUEST.fields_by_name['timestamp']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\020yaml:\"timestamp\"'
  _ACCOUNTLOCKEDPASTTIMERESPONSE.fields_by_name['locks']._options = None
  _ACCOUNTLOCKEDPASTTIMERESPONSE.fields_by_name['locks']._serialized_options = b'\310\336\037\000'
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYREQUEST.fields_by_name['timestamp']._options = None
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYREQUEST.fields_by_name['timestamp']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\020yaml:\"timestamp\"'
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYRESPONSE.fields_by_name['locks']._options = None
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYRESPONSE.fields_by_name['locks']._serialized_options = b'\310\336\037\000'
  _ACCOUNTUNLOCKEDBEFORETIMEREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTUNLOCKEDBEFORETIMEREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTUNLOCKEDBEFORETIMEREQUEST.fields_by_name['timestamp']._options = None
  _ACCOUNTUNLOCKEDBEFORETIMEREQUEST.fields_by_name['timestamp']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\020yaml:\"timestamp\"'
  _ACCOUNTUNLOCKEDBEFORETIMERESPONSE.fields_by_name['locks']._options = None
  _ACCOUNTUNLOCKEDBEFORETIMERESPONSE.fields_by_name['locks']._serialized_options = b'\310\336\037\000'
  _ACCOUNTLOCKEDPASTTIMEDENOMREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTLOCKEDPASTTIMEDENOMREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTLOCKEDPASTTIMEDENOMREQUEST.fields_by_name['timestamp']._options = None
  _ACCOUNTLOCKEDPASTTIMEDENOMREQUEST.fields_by_name['timestamp']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\020yaml:\"timestamp\"'
  _ACCOUNTLOCKEDPASTTIMEDENOMRESPONSE.fields_by_name['locks']._options = None
  _ACCOUNTLOCKEDPASTTIMEDENOMRESPONSE.fields_by_name['locks']._serialized_options = b'\310\336\037\000'
  _LOCKEDDENOMREQUEST.fields_by_name['duration']._options = None
  _LOCKEDDENOMREQUEST.fields_by_name['duration']._serialized_options = b'\230\337\037\001\310\336\037\000\362\336\037\017yaml:\"duration\"'
  _LOCKEDDENOMRESPONSE.fields_by_name['amount']._options = None
  _LOCKEDDENOMRESPONSE.fields_by_name['amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\ryaml:\"amount\"\310\336\037\000'
  _SYNTHETICLOCKUPSBYLOCKUPIDRESPONSE.fields_by_name['synthetic_locks']._options = None
  _SYNTHETICLOCKUPSBYLOCKUPIDRESPONSE.fields_by_name['synthetic_locks']._serialized_options = b'\310\336\037\000'
  _ACCOUNTLOCKEDLONGERDURATIONREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTLOCKEDLONGERDURATIONREQUEST.fields_by_name['duration']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONREQUEST.fields_by_name['duration']._serialized_options = b'\230\337\037\001\310\336\037\000\362\336\037\017yaml:\"duration\"'
  _ACCOUNTLOCKEDLONGERDURATIONRESPONSE.fields_by_name['locks']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONRESPONSE.fields_by_name['locks']._serialized_options = b'\310\336\037\000'
  _ACCOUNTLOCKEDDURATIONREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTLOCKEDDURATIONREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTLOCKEDDURATIONREQUEST.fields_by_name['duration']._options = None
  _ACCOUNTLOCKEDDURATIONREQUEST.fields_by_name['duration']._serialized_options = b'\230\337\037\001\310\336\037\000\362\336\037\017yaml:\"duration\"'
  _ACCOUNTLOCKEDDURATIONRESPONSE.fields_by_name['locks']._options = None
  _ACCOUNTLOCKEDDURATIONRESPONSE.fields_by_name['locks']._serialized_options = b'\310\336\037\000'
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYREQUEST.fields_by_name['duration']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYREQUEST.fields_by_name['duration']._serialized_options = b'\230\337\037\001\310\336\037\000\362\336\037\017yaml:\"duration\"'
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYRESPONSE.fields_by_name['locks']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYRESPONSE.fields_by_name['locks']._serialized_options = b'\310\336\037\000'
  _ACCOUNTLOCKEDLONGERDURATIONDENOMREQUEST.fields_by_name['owner']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONDENOMREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _ACCOUNTLOCKEDLONGERDURATIONDENOMREQUEST.fields_by_name['duration']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONDENOMREQUEST.fields_by_name['duration']._serialized_options = b'\230\337\037\001\310\336\037\000\362\336\037\017yaml:\"duration\"'
  _ACCOUNTLOCKEDLONGERDURATIONDENOMRESPONSE.fields_by_name['locks']._options = None
  _ACCOUNTLOCKEDLONGERDURATIONDENOMRESPONSE.fields_by_name['locks']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['ModuleBalance']._options = None
  _QUERY.methods_by_name['ModuleBalance']._serialized_options = b'\202\323\344\223\002(\022&/osmosis/lockup/v1beta1/module_balance'
  _QUERY.methods_by_name['ModuleLockedAmount']._options = None
  _QUERY.methods_by_name['ModuleLockedAmount']._serialized_options = b'\202\323\344\223\002.\022,/osmosis/lockup/v1beta1/module_locked_amount'
  _QUERY.methods_by_name['AccountUnlockableCoins']._options = None
  _QUERY.methods_by_name['AccountUnlockableCoins']._serialized_options = b'\202\323\344\223\002:\0228/osmosis/lockup/v1beta1/account_unlockable_coins/{owner}'
  _QUERY.methods_by_name['AccountUnlockingCoins']._options = None
  _QUERY.methods_by_name['AccountUnlockingCoins']._serialized_options = b'\202\323\344\223\0029\0227/osmosis/lockup/v1beta1/account_unlocking_coins/{owner}'
  _QUERY.methods_by_name['AccountLockedCoins']._options = None
  _QUERY.methods_by_name['AccountLockedCoins']._serialized_options = b'\202\323\344\223\0026\0224/osmosis/lockup/v1beta1/account_locked_coins/{owner}'
  _QUERY.methods_by_name['AccountLockedPastTime']._options = None
  _QUERY.methods_by_name['AccountLockedPastTime']._serialized_options = b'\202\323\344\223\0029\0227/osmosis/lockup/v1beta1/account_locked_pasttime/{owner}'
  _QUERY.methods_by_name['AccountLockedPastTimeNotUnlockingOnly']._options = None
  _QUERY.methods_by_name['AccountLockedPastTimeNotUnlockingOnly']._serialized_options = b'\202\323\344\223\002L\022J/osmosis/lockup/v1beta1/account_locked_pasttime_not_unlocking_only/{owner}'
  _QUERY.methods_by_name['AccountUnlockedBeforeTime']._options = None
  _QUERY.methods_by_name['AccountUnlockedBeforeTime']._serialized_options = b'\202\323\344\223\002>\022</osmosis/lockup/v1beta1/account_unlocked_before_time/{owner}'
  _QUERY.methods_by_name['AccountLockedPastTimeDenom']._options = None
  _QUERY.methods_by_name['AccountLockedPastTimeDenom']._serialized_options = b'\202\323\344\223\002?\022=/osmosis/lockup/v1beta1/account_locked_pasttime_denom/{owner}'
  _QUERY.methods_by_name['LockedDenom']._options = None
  _QUERY.methods_by_name['LockedDenom']._serialized_options = b'\202\323\344\223\002&\022$/osmosis/lockup/v1beta1/locked_denom'
  _QUERY.methods_by_name['LockedByID']._options = None
  _QUERY.methods_by_name['LockedByID']._serialized_options = b'\202\323\344\223\0020\022./osmosis/lockup/v1beta1/locked_by_id/{lock_id}'
  _QUERY.methods_by_name['SyntheticLockupsByLockupID']._options = None
  _QUERY.methods_by_name['SyntheticLockupsByLockupID']._serialized_options = b'\202\323\344\223\002@\022>/osmosis/lockup/v1beta1/synthetic_lockups_by_lock_id/{lock_id}'
  _QUERY.methods_by_name['AccountLockedLongerDuration']._options = None
  _QUERY.methods_by_name['AccountLockedLongerDuration']._serialized_options = b'\202\323\344\223\002@\022>/osmosis/lockup/v1beta1/account_locked_longer_duration/{owner}'
  _QUERY.methods_by_name['AccountLockedDuration']._options = None
  _QUERY.methods_by_name['AccountLockedDuration']._serialized_options = b'\202\323\344\223\0029\0227/osmosis/lockup/v1beta1/account_locked_duration/{owner}'
  _QUERY.methods_by_name['AccountLockedLongerDurationNotUnlockingOnly']._options = None
  _QUERY.methods_by_name['AccountLockedLongerDurationNotUnlockingOnly']._serialized_options = b'\202\323\344\223\002S\022Q/osmosis/lockup/v1beta1/account_locked_longer_duration_not_unlocking_only/{owner}'
  _QUERY.methods_by_name['AccountLockedLongerDurationDenom']._options = None
  _QUERY.methods_by_name['AccountLockedLongerDurationDenom']._serialized_options = b'\202\323\344\223\002F\022D/osmosis/lockup/v1beta1/account_locked_longer_duration_denom/{owner}'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002 \022\036/osmosis/lockup/v1beta1/params'
  _MODULEBALANCEREQUEST._serialized_start=251
  _MODULEBALANCEREQUEST._serialized_end=273
  _MODULEBALANCERESPONSE._serialized_start=275
  _MODULEBALANCERESPONSE._serialized_end=390
  _MODULELOCKEDAMOUNTREQUEST._serialized_start=392
  _MODULELOCKEDAMOUNTREQUEST._serialized_end=419
  _MODULELOCKEDAMOUNTRESPONSE._serialized_start=421
  _MODULELOCKEDAMOUNTRESPONSE._serialized_end=541
  _ACCOUNTUNLOCKABLECOINSREQUEST._serialized_start=543
  _ACCOUNTUNLOCKABLECOINSREQUEST._serialized_end=607
  _ACCOUNTUNLOCKABLECOINSRESPONSE._serialized_start=609
  _ACCOUNTUNLOCKABLECOINSRESPONSE._serialized_end=733
  _ACCOUNTUNLOCKINGCOINSREQUEST._serialized_start=735
  _ACCOUNTUNLOCKINGCOINSREQUEST._serialized_end=798
  _ACCOUNTUNLOCKINGCOINSRESPONSE._serialized_start=800
  _ACCOUNTUNLOCKINGCOINSRESPONSE._serialized_end=923
  _ACCOUNTLOCKEDCOINSREQUEST._serialized_start=925
  _ACCOUNTLOCKEDCOINSREQUEST._serialized_end=985
  _ACCOUNTLOCKEDCOINSRESPONSE._serialized_start=987
  _ACCOUNTLOCKEDCOINSRESPONSE._serialized_end=1107
  _ACCOUNTLOCKEDPASTTIMEREQUEST._serialized_start=1110
  _ACCOUNTLOCKEDPASTTIMEREQUEST._serialized_end=1250
  _ACCOUNTLOCKEDPASTTIMERESPONSE._serialized_start=1252
  _ACCOUNTLOCKEDPASTTIMERESPONSE._serialized_end=1332
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYREQUEST._serialized_start=1335
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYREQUEST._serialized_end=1491
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYRESPONSE._serialized_start=1493
  _ACCOUNTLOCKEDPASTTIMENOTUNLOCKINGONLYRESPONSE._serialized_end=1589
  _ACCOUNTUNLOCKEDBEFORETIMEREQUEST._serialized_start=1592
  _ACCOUNTUNLOCKEDBEFORETIMEREQUEST._serialized_end=1736
  _ACCOUNTUNLOCKEDBEFORETIMERESPONSE._serialized_start=1738
  _ACCOUNTUNLOCKEDBEFORETIMERESPONSE._serialized_end=1822
  _ACCOUNTLOCKEDPASTTIMEDENOMREQUEST._serialized_start=1825
  _ACCOUNTLOCKEDPASTTIMEDENOMREQUEST._serialized_end=1985
  _ACCOUNTLOCKEDPASTTIMEDENOMRESPONSE._serialized_start=1987
  _ACCOUNTLOCKEDPASTTIMEDENOMRESPONSE._serialized_end=2072
  _LOCKEDDENOMREQUEST._serialized_start=2074
  _LOCKEDDENOMREQUEST._serialized_end=2183
  _LOCKEDDENOMRESPONSE._serialized_start=2185
  _LOCKEDDENOMRESPONSE._serialized_end=2287
  _LOCKEDREQUEST._serialized_start=2289
  _LOCKEDREQUEST._serialized_end=2321
  _LOCKEDRESPONSE._serialized_start=2323
  _LOCKEDRESPONSE._serialized_end=2381
  _SYNTHETICLOCKUPSBYLOCKUPIDREQUEST._serialized_start=2383
  _SYNTHETICLOCKUPSBYLOCKUPIDREQUEST._serialized_end=2435
  _SYNTHETICLOCKUPSBYLOCKUPIDRESPONSE._serialized_start=2437
  _SYNTHETICLOCKUPSBYLOCKUPIDRESPONSE._serialized_end=2535
  _ACCOUNTLOCKEDLONGERDURATIONREQUEST._serialized_start=2538
  _ACCOUNTLOCKEDLONGERDURATIONREQUEST._serialized_end=2681
  _ACCOUNTLOCKEDLONGERDURATIONRESPONSE._serialized_start=2683
  _ACCOUNTLOCKEDLONGERDURATIONRESPONSE._serialized_end=2769
  _ACCOUNTLOCKEDDURATIONREQUEST._serialized_start=2772
  _ACCOUNTLOCKEDDURATIONREQUEST._serialized_end=2909
  _ACCOUNTLOCKEDDURATIONRESPONSE._serialized_start=2911
  _ACCOUNTLOCKEDDURATIONRESPONSE._serialized_end=2991
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYREQUEST._serialized_start=2994
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYREQUEST._serialized_end=3153
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYRESPONSE._serialized_start=3155
  _ACCOUNTLOCKEDLONGERDURATIONNOTUNLOCKINGONLYRESPONSE._serialized_end=3257
  _ACCOUNTLOCKEDLONGERDURATIONDENOMREQUEST._serialized_start=3260
  _ACCOUNTLOCKEDLONGERDURATIONDENOMREQUEST._serialized_end=3423
  _ACCOUNTLOCKEDLONGERDURATIONDENOMRESPONSE._serialized_start=3425
  _ACCOUNTLOCKEDLONGERDURATIONDENOMRESPONSE._serialized_end=3516
  _QUERYPARAMSREQUEST._serialized_start=3518
  _QUERYPARAMSREQUEST._serialized_end=3538
  _QUERYPARAMSRESPONSE._serialized_start=3540
  _QUERYPARAMSRESPONSE._serialized_end=3607
  _QUERY._serialized_start=3610
  _QUERY._serialized_end=6806
# @@protoc_insertion_point(module_scope)
