"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Params(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MINTED_DENOM_FIELD_NUMBER: builtins.int
    minted_denom: builtins.str
    """minted_denom is the denomination of the coin expected to be minted by the
    minting module. Pool-incentives module doesn’t actually mint the coin
    itself, but rather manages the distribution of coins that matches the
    defined minted_denom.
    """
    def __init__(
        self,
        *,
        minted_denom: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["minted_denom", b"minted_denom"]) -> None: ...

global___Params = Params

@typing_extensions.final
class LockableDurationsInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCKABLE_DURATIONS_FIELD_NUMBER: builtins.int
    @property
    def lockable_durations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.duration_pb2.Duration]: ...
    def __init__(
        self,
        *,
        lockable_durations: collections.abc.Iterable[google.protobuf.duration_pb2.Duration] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lockable_durations", b"lockable_durations"]) -> None: ...

global___LockableDurationsInfo = LockableDurationsInfo

@typing_extensions.final
class DistrInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOTAL_WEIGHT_FIELD_NUMBER: builtins.int
    RECORDS_FIELD_NUMBER: builtins.int
    total_weight: builtins.str
    @property
    def records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DistrRecord]: ...
    def __init__(
        self,
        *,
        total_weight: builtins.str = ...,
        records: collections.abc.Iterable[global___DistrRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["records", b"records", "total_weight", b"total_weight"]) -> None: ...

global___DistrInfo = DistrInfo

@typing_extensions.final
class DistrRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GAUGE_ID_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    gauge_id: builtins.int
    weight: builtins.str
    def __init__(
        self,
        *,
        gauge_id: builtins.int = ...,
        weight: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gauge_id", b"gauge_id", "weight", b"weight"]) -> None: ...

global___DistrRecord = DistrRecord

@typing_extensions.final
class PoolToGauge(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    GAUGE_ID_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    gauge_id: builtins.int
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        gauge_id: builtins.int = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration", "gauge_id", b"gauge_id", "pool_id", b"pool_id"]) -> None: ...

global___PoolToGauge = PoolToGauge

@typing_extensions.final
class PoolToGauges(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_TO_GAUGE_FIELD_NUMBER: builtins.int
    @property
    def pool_to_gauge(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PoolToGauge]: ...
    def __init__(
        self,
        *,
        pool_to_gauge: collections.abc.Iterable[global___PoolToGauge] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_to_gauge", b"pool_to_gauge"]) -> None: ...

global___PoolToGauges = PoolToGauges
