"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import osmosis.txfees.v1beta1.feetoken_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class UpdateFeeTokenProposal(google.protobuf.message.Message):
    """UpdateFeeTokenProposal is a gov Content type for adding a new whitelisted fee
    token. It must specify a denom along with gamm pool ID to use as a spot price
    calculator. It can be used to add a new denom to the whitelist It can also be
    used to update the Pool to associate with the denom. If Pool ID is set to 0,
    it will remove the denom from the whitelisted set.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FEETOKEN_FIELD_NUMBER: builtins.int
    title: builtins.str
    description: builtins.str
    @property
    def feetoken(self) -> osmosis.txfees.v1beta1.feetoken_pb2.FeeToken: ...
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
        feetoken: osmosis.txfees.v1beta1.feetoken_pb2.FeeToken | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feetoken", b"feetoken"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "feetoken", b"feetoken", "title", b"title"]) -> None: ...

global___UpdateFeeTokenProposal = UpdateFeeTokenProposal
