"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.gamm.v2.query_pb2

class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    SpotPrice: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v2.query_pb2.QuerySpotPriceRequest,
        osmosis.gamm.v2.query_pb2.QuerySpotPriceResponse,
    ]
    """SpotPrice defines a gRPC query handler that returns the spot price given
    a base denomination and a quote denomination.
    """

class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def SpotPrice(
        self,
        request: osmosis.gamm.v2.query_pb2.QuerySpotPriceRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v2.query_pb2.QuerySpotPriceResponse:
        """SpotPrice defines a gRPC query handler that returns the spot price given
        a base denomination and a quote denomination.
        """

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...
