"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.gamm.pool_models.balancer.balancerPool_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MsgCreateBalancerPool(google.protobuf.message.Message):
    """===================== MsgCreatePool"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    POOL_PARAMS_FIELD_NUMBER: builtins.int
    POOL_ASSETS_FIELD_NUMBER: builtins.int
    FUTURE_POOL_GOVERNOR_FIELD_NUMBER: builtins.int
    sender: builtins.str
    @property
    def pool_params(self) -> osmosis.gamm.pool_models.balancer.balancerPool_pb2.PoolParams: ...
    @property
    def pool_assets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.gamm.pool_models.balancer.balancerPool_pb2.PoolAsset]: ...
    future_pool_governor: builtins.str
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        pool_params: osmosis.gamm.pool_models.balancer.balancerPool_pb2.PoolParams | None = ...,
        pool_assets: collections.abc.Iterable[osmosis.gamm.pool_models.balancer.balancerPool_pb2.PoolAsset] | None = ...,
        future_pool_governor: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pool_params", b"pool_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["future_pool_governor", b"future_pool_governor", "pool_assets", b"pool_assets", "pool_params", b"pool_params", "sender", b"sender"]) -> None: ...

global___MsgCreateBalancerPool = MsgCreateBalancerPool

@typing_extensions.final
class MsgCreateBalancerPoolResponse(google.protobuf.message.Message):
    """Returns the poolID"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id"]) -> None: ...

global___MsgCreateBalancerPoolResponse = MsgCreateBalancerPoolResponse
