# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/mint/v1beta1/mint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fosmosis/mint/v1beta1/mint.proto\x12\x14osmosis.mint.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\"m\n\x06Minter\x12\x63\n\x10\x65poch_provisions\x18\x01 \x01(\tBI\xf2\xde\x1f\x17yaml:\"epoch_provisions\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x87\x01\n\x0fWeightedAddress\x12#\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"\x12O\n\x06weight\x18\x02 \x01(\tB?\xf2\xde\x1f\ryaml:\"weight\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x97\x03\n\x17\x44istributionProportions\x12Q\n\x07staking\x18\x01 \x01(\tB@\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x0eyaml:\"staking\"\xc8\xde\x1f\x00\x12\x61\n\x0fpool_incentives\x18\x02 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x16yaml:\"pool_incentives\"\xc8\xde\x1f\x00\x12\x65\n\x11\x64\x65veloper_rewards\x18\x03 \x01(\tBJ\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x18yaml:\"developer_rewards\"\xc8\xde\x1f\x00\x12_\n\x0e\x63ommunity_pool\x18\x04 \x01(\tBG\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x15yaml:\"community_pool\"\xc8\xde\x1f\x00\"\xbc\x05\n\x06Params\x12\x12\n\nmint_denom\x18\x01 \x01(\t\x12s\n\x18genesis_epoch_provisions\x18\x02 \x01(\tBQ\xf2\xde\x1f\x1fyaml:\"genesis_epoch_provisions\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x35\n\x10\x65poch_identifier\x18\x03 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"epoch_identifier\"\x12I\n\x1areduction_period_in_epochs\x18\x04 \x01(\x03\x42%\xf2\xde\x1f!yaml:\"reduction_period_in_epochs\"\x12\x63\n\x10reduction_factor\x18\x05 \x01(\tBI\xf2\xde\x1f\x17yaml:\"reduction_factor\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12U\n\x18\x64istribution_proportions\x18\x06 \x01(\x0b\x32-.osmosis.mint.v1beta1.DistributionProportionsB\x04\xc8\xde\x1f\x00\x12~\n$weighted_developer_rewards_receivers\x18\x07 \x03(\x0b\x32%.osmosis.mint.v1beta1.WeightedAddressB)\xf2\xde\x1f!yaml:\"developer_rewards_receiver\"\xc8\xde\x1f\x00\x12\x65\n(minting_rewards_distribution_start_epoch\x18\x08 \x01(\x03\x42\x33\xf2\xde\x1f/yaml:\"minting_rewards_distribution_start_epoch\":\x04\x98\xa0\x1f\x00\x42\x32Z0github.com/osmosis-labs/osmosis/v14/x/mint/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.mint.v1beta1.mint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/osmosis-labs/osmosis/v14/x/mint/types'
  _MINTER.fields_by_name['epoch_provisions']._options = None
  _MINTER.fields_by_name['epoch_provisions']._serialized_options = b'\362\336\037\027yaml:\"epoch_provisions\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _WEIGHTEDADDRESS.fields_by_name['address']._options = None
  _WEIGHTEDADDRESS.fields_by_name['address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _WEIGHTEDADDRESS.fields_by_name['weight']._options = None
  _WEIGHTEDADDRESS.fields_by_name['weight']._serialized_options = b'\362\336\037\ryaml:\"weight\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DISTRIBUTIONPROPORTIONS.fields_by_name['staking']._options = None
  _DISTRIBUTIONPROPORTIONS.fields_by_name['staking']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\016yaml:\"staking\"\310\336\037\000'
  _DISTRIBUTIONPROPORTIONS.fields_by_name['pool_incentives']._options = None
  _DISTRIBUTIONPROPORTIONS.fields_by_name['pool_incentives']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\026yaml:\"pool_incentives\"\310\336\037\000'
  _DISTRIBUTIONPROPORTIONS.fields_by_name['developer_rewards']._options = None
  _DISTRIBUTIONPROPORTIONS.fields_by_name['developer_rewards']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\030yaml:\"developer_rewards\"\310\336\037\000'
  _DISTRIBUTIONPROPORTIONS.fields_by_name['community_pool']._options = None
  _DISTRIBUTIONPROPORTIONS.fields_by_name['community_pool']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\025yaml:\"community_pool\"\310\336\037\000'
  _PARAMS.fields_by_name['genesis_epoch_provisions']._options = None
  _PARAMS.fields_by_name['genesis_epoch_provisions']._serialized_options = b'\362\336\037\037yaml:\"genesis_epoch_provisions\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['epoch_identifier']._options = None
  _PARAMS.fields_by_name['epoch_identifier']._serialized_options = b'\362\336\037\027yaml:\"epoch_identifier\"'
  _PARAMS.fields_by_name['reduction_period_in_epochs']._options = None
  _PARAMS.fields_by_name['reduction_period_in_epochs']._serialized_options = b'\362\336\037!yaml:\"reduction_period_in_epochs\"'
  _PARAMS.fields_by_name['reduction_factor']._options = None
  _PARAMS.fields_by_name['reduction_factor']._serialized_options = b'\362\336\037\027yaml:\"reduction_factor\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['distribution_proportions']._options = None
  _PARAMS.fields_by_name['distribution_proportions']._serialized_options = b'\310\336\037\000'
  _PARAMS.fields_by_name['weighted_developer_rewards_receivers']._options = None
  _PARAMS.fields_by_name['weighted_developer_rewards_receivers']._serialized_options = b'\362\336\037!yaml:\"developer_rewards_receiver\"\310\336\037\000'
  _PARAMS.fields_by_name['minting_rewards_distribution_start_epoch']._options = None
  _PARAMS.fields_by_name['minting_rewards_distribution_start_epoch']._serialized_options = b'\362\336\037/yaml:\"minting_rewards_distribution_start_epoch\"'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\230\240\037\000'
  _MINTER._serialized_start=171
  _MINTER._serialized_end=280
  _WEIGHTEDADDRESS._serialized_start=283
  _WEIGHTEDADDRESS._serialized_end=418
  _DISTRIBUTIONPROPORTIONS._serialized_start=421
  _DISTRIBUTIONPROPORTIONS._serialized_end=828
  _PARAMS._serialized_start=831
  _PARAMS._serialized_end=1531
# @@protoc_insertion_point(module_scope)
