"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MsgVerifyInvariant(google.protobuf.message.Message):
    """MsgVerifyInvariant represents a message to verify a particular invariance."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    INVARIANT_MODULE_NAME_FIELD_NUMBER: builtins.int
    INVARIANT_ROUTE_FIELD_NUMBER: builtins.int
    sender: builtins.str
    invariant_module_name: builtins.str
    invariant_route: builtins.str
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        invariant_module_name: builtins.str = ...,
        invariant_route: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["invariant_module_name", b"invariant_module_name", "invariant_route", b"invariant_route", "sender", b"sender"]) -> None: ...

global___MsgVerifyInvariant = MsgVerifyInvariant

@typing_extensions.final
class MsgVerifyInvariantResponse(google.protobuf.message.Message):
    """MsgVerifyInvariantResponse defines the Msg/VerifyInvariant response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgVerifyInvariantResponse = MsgVerifyInvariantResponse
