"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Since: cosmos-sdk 0.43"""
import builtins
import collections.abc
import cosmos.base.query.v1beta1.pagination_pb2
import cosmos.feegrant.v1beta1.feegrant_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QueryAllowanceRequest(google.protobuf.message.Message):
    """QueryAllowanceRequest is the request type for the Query/Allowance RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    granter: builtins.str
    """granter is the address of the user granting an allowance of their funds."""
    grantee: builtins.str
    """grantee is the address of the user being granted an allowance of another user's funds."""
    def __init__(
        self,
        *,
        granter: builtins.str = ...,
        grantee: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["grantee", b"grantee", "granter", b"granter"]) -> None: ...

global___QueryAllowanceRequest = QueryAllowanceRequest

@typing_extensions.final
class QueryAllowanceResponse(google.protobuf.message.Message):
    """QueryAllowanceResponse is the response type for the Query/Allowance RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWANCE_FIELD_NUMBER: builtins.int
    @property
    def allowance(self) -> cosmos.feegrant.v1beta1.feegrant_pb2.Grant:
        """allowance is a allowance granted for grantee by granter."""
    def __init__(
        self,
        *,
        allowance: cosmos.feegrant.v1beta1.feegrant_pb2.Grant | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["allowance", b"allowance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowance", b"allowance"]) -> None: ...

global___QueryAllowanceResponse = QueryAllowanceResponse

@typing_extensions.final
class QueryAllowancesRequest(google.protobuf.message.Message):
    """QueryAllowancesRequest is the request type for the Query/Allowances RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GRANTEE_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    grantee: builtins.str
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an pagination for the request."""
    def __init__(
        self,
        *,
        grantee: builtins.str = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["grantee", b"grantee", "pagination", b"pagination"]) -> None: ...

global___QueryAllowancesRequest = QueryAllowancesRequest

@typing_extensions.final
class QueryAllowancesResponse(google.protobuf.message.Message):
    """QueryAllowancesResponse is the response type for the Query/Allowances RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWANCES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def allowances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.feegrant.v1beta1.feegrant_pb2.Grant]:
        """allowances are allowance's granted for grantee by granter."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines an pagination for the response."""
    def __init__(
        self,
        *,
        allowances: collections.abc.Iterable[cosmos.feegrant.v1beta1.feegrant_pb2.Grant] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowances", b"allowances", "pagination", b"pagination"]) -> None: ...

global___QueryAllowancesResponse = QueryAllowancesResponse
