# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from osmosis.incentives import tx_pb2 as osmosis_dot_incentives_dot_tx__pb2


class MsgStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateGauge = channel.unary_unary(
                '/osmosis.incentives.Msg/CreateGauge',
                request_serializer=osmosis_dot_incentives_dot_tx__pb2.MsgCreateGauge.SerializeToString,
                response_deserializer=osmosis_dot_incentives_dot_tx__pb2.MsgCreateGaugeResponse.FromString,
                )
        self.AddToGauge = channel.unary_unary(
                '/osmosis.incentives.Msg/AddToGauge',
                request_serializer=osmosis_dot_incentives_dot_tx__pb2.MsgAddToGauge.SerializeToString,
                response_deserializer=osmosis_dot_incentives_dot_tx__pb2.MsgAddToGaugeResponse.FromString,
                )


class MsgServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateGauge(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddToGauge(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateGauge': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateGauge,
                    request_deserializer=osmosis_dot_incentives_dot_tx__pb2.MsgCreateGauge.FromString,
                    response_serializer=osmosis_dot_incentives_dot_tx__pb2.MsgCreateGaugeResponse.SerializeToString,
            ),
            'AddToGauge': grpc.unary_unary_rpc_method_handler(
                    servicer.AddToGauge,
                    request_deserializer=osmosis_dot_incentives_dot_tx__pb2.MsgAddToGauge.FromString,
                    response_serializer=osmosis_dot_incentives_dot_tx__pb2.MsgAddToGaugeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'osmosis.incentives.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateGauge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.incentives.Msg/CreateGauge',
            osmosis_dot_incentives_dot_tx__pb2.MsgCreateGauge.SerializeToString,
            osmosis_dot_incentives_dot_tx__pb2.MsgCreateGaugeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddToGauge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.incentives.Msg/AddToGauge',
            osmosis_dot_incentives_dot_tx__pb2.MsgAddToGauge.SerializeToString,
            osmosis_dot_incentives_dot_tx__pb2.MsgAddToGaugeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
